@@ -26,6 +26,10 @@
  * This program is written to show how to use nghttp2 API in C and
  * intentionally made simple.
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif /* !HAVE_CONFIG_H */
+
 #include <stdint.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -46,19 +50,19 @@
 #include <openssl/err.h>
 #include <openssl/conf.h>
 
-enum {
-  IO_NONE,
-  WANT_READ,
-  WANT_WRITE
-};
+enum { IO_NONE, WANT_READ, WANT_WRITE };
 
-#define MAKE_NV(NAME, VALUE)                                            \
-  {(uint8_t*)NAME, (uint8_t*)VALUE, sizeof(NAME) - 1, sizeof(VALUE) - 1, \
-      NGHTTP2_NV_FLAG_NONE}
+#define MAKE_NV(NAME, VALUE)                                                   \
+  {                                                                            \
+    (uint8_t *) NAME, (uint8_t *)VALUE, sizeof(NAME) - 1, sizeof(VALUE) - 1,   \
+        NGHTTP2_NV_FLAG_NONE                                                   \
+  }
 
-#define MAKE_NV_CS(NAME, VALUE)                                         \
-  {(uint8_t*)NAME, (uint8_t*)VALUE, sizeof(NAME) - 1, strlen(VALUE),    \
-      NGHTTP2_NV_FLAG_NONE}
+#define MAKE_NV_CS(NAME, VALUE)                                                \
+  {                                                                            \
+    (uint8_t *) NAME, (uint8_t *)VALUE, sizeof(NAME) - 1, strlen(VALUE),       \
+        NGHTTP2_NV_FLAG_NONE                                                   \
+  }
 
 struct Connection {
   SSL *ssl;
@@ -99,10 +103,9 @@ struct URI {
  * Returns copy of string |s| with the length |len|. The returned
  * string is NULL-terminated.
  */
-static char* strcopy(const char *s, size_t len)
-{
+static char *strcopy(const char *s, size_t len) {
   char *dst;
-  dst = malloc(len+1);
+  dst = malloc(len + 1);
   memcpy(dst, s, len);
   dst[len] = '\0';
   return dst;
@@ -111,8 +114,7 @@ static char* strcopy(const char *s, size_t len)
 /*
  * Prints error message |msg| and exit.
  */
-static void die(const char *msg)
-{
+static void die(const char *msg) {
   fprintf(stderr, "FATAL: %s\n", msg);
   exit(EXIT_FAILURE);
 }
@@ -121,8 +123,7 @@ static void die(const char *msg)
  * Prints error containing the function name |func| and message |msg|
  * and exit.
  */
-static void dief(const char *func, const char *msg)
-{
+static void dief(const char *func, const char *msg) {
   fprintf(stderr, "FATAL: %s: %s\n", func, msg);
   exit(EXIT_FAILURE);
 }
@@ -131,8 +132,7 @@ static void dief(const char *func, const char *msg)
  * Prints error containing the function name |func| and error code
  * |error_code| and exit.
  */
-static void diec(const char *func, int error_code)
-{
+static void diec(const char *func, int error_code) {
   fprintf(stderr, "FATAL: %s: error_code=%d, msg=%s\n", func, error_code,
           nghttp2_strerror(error_code));
   exit(EXIT_FAILURE);
@@ -144,21 +144,19 @@ static void diec(const char *func, int error_code)
  * bytes actually written. See the documentation of
  * nghttp2_send_callback for the details.
  */
-static ssize_t send_callback(nghttp2_session *session,
-                             const uint8_t *data, size_t length, int flags,
-                             void *user_data)
-{
+static ssize_t send_callback(nghttp2_session *session _U_, const uint8_t *data,
+                             size_t length, int flags _U_, void *user_data) {
   struct Connection *connection;
   int rv;
-  connection = (struct Connection*)user_data;
+  connection = (struct Connection *)user_data;
   connection->want_io = IO_NONE;
   ERR_clear_error();
   rv = SSL_write(connection->ssl, data, (int)length);
-  if(rv < 0) {
+  if (rv < 0) {
     int err = SSL_get_error(connection->ssl, rv);
-    if(err == SSL_ERROR_WANT_WRITE || err == SSL_ERROR_WANT_READ) {
-      connection->want_io = (err == SSL_ERROR_WANT_READ ?
-                             WANT_READ : WANT_WRITE);
+    if (err == SSL_ERROR_WANT_WRITE || err == SSL_ERROR_WANT_READ) {
+      connection->want_io =
+          (err == SSL_ERROR_WANT_READ ? WANT_READ : WANT_WRITE);
       rv = NGHTTP2_ERR_WOULDBLOCK;
     } else {
       rv = NGHTTP2_ERR_CALLBACK_FAILURE;
@@ -173,41 +171,39 @@ static ssize_t send_callback(nghttp2_session *session,
  * |length| bytes. Returns the number of bytes stored in |buf|. See
  * the documentation of nghttp2_recv_callback for the details.
  */
-static ssize_t recv_callback(nghttp2_session *session,
-                             uint8_t *buf, size_t length, int flags,
-                             void *user_data)
-{
+static ssize_t recv_callback(nghttp2_session *session _U_, uint8_t *buf,
+                             size_t length, int flags _U_, void *user_data) {
   struct Connection *connection;
   int rv;
-  connection = (struct Connection*)user_data;
+  connection = (struct Connection *)user_data;
   connection->want_io = IO_NONE;
   ERR_clear_error();
   rv = SSL_read(connection->ssl, buf, (int)length);
-  if(rv < 0) {
+  if (rv < 0) {
     int err = SSL_get_error(connection->ssl, rv);
-    if(err == SSL_ERROR_WANT_WRITE || err == SSL_ERROR_WANT_READ) {
-      connection->want_io = (err == SSL_ERROR_WANT_READ ?
-                             WANT_READ : WANT_WRITE);
+    if (err == SSL_ERROR_WANT_WRITE || err == SSL_ERROR_WANT_READ) {
+      connection->want_io =
+          (err == SSL_ERROR_WANT_READ ? WANT_READ : WANT_WRITE);
       rv = NGHTTP2_ERR_WOULDBLOCK;
     } else {
       rv = NGHTTP2_ERR_CALLBACK_FAILURE;
     }
-  } else if(rv == 0) {
+  } else if (rv == 0) {
     rv = NGHTTP2_ERR_EOF;
   }
   return rv;
 }
 
 static int on_frame_send_callback(nghttp2_session *session,
-                                  const nghttp2_frame *frame, void *user_data)
-{
+                                  const nghttp2_frame *frame,
+                                  void *user_data _U_) {
   size_t i;
-  switch(frame->hd.type) {
+  switch (frame->hd.type) {
   case NGHTTP2_HEADERS:
-    if(nghttp2_session_get_stream_user_data(session, frame->hd.stream_id)) {
+    if (nghttp2_session_get_stream_user_data(session, frame->hd.stream_id)) {
       const nghttp2_nv *nva = frame->headers.nva;
       printf("[INFO] C ----------------------------> S (HEADERS)\n");
-      for(i = 0; i < frame->headers.nvlen; ++i) {
+      for (i = 0; i < frame->headers.nvlen; ++i) {
         fwrite(nva[i].name, nva[i].namelen, 1, stdout);
         printf(": ");
         fwrite(nva[i].value, nva[i].valuelen, 1, stdout);
@@ -226,18 +222,18 @@ static int on_frame_send_callback(nghttp2_session *session,
 }
 
 static int on_frame_recv_callback(nghttp2_session *session,
-                                  const nghttp2_frame *frame, void *user_data)
-{
+                                  const nghttp2_frame *frame,
+                                  void *user_data _U_) {
   size_t i;
-  switch(frame->hd.type) {
+  switch (frame->hd.type) {
   case NGHTTP2_HEADERS:
-    if(frame->headers.cat == NGHTTP2_HCAT_RESPONSE) {
+    if (frame->headers.cat == NGHTTP2_HCAT_RESPONSE) {
       const nghttp2_nv *nva = frame->headers.nva;
       struct Request *req;
       req = nghttp2_session_get_stream_user_data(session, frame->hd.stream_id);
-      if(req) {
+      if (req) {
         printf("[INFO] C <---------------------------- S (HEADERS)\n");
-        for(i = 0; i < frame->headers.nvlen; ++i) {
+        for (i = 0; i < frame->headers.nvlen; ++i) {
           fwrite(nva[i].name, nva[i].namelen, 1, stdout);
           printf(": ");
           fwrite(nva[i].value, nva[i].valuelen, 1, stdout);
@@ -262,18 +258,16 @@ static int on_frame_recv_callback(nghttp2_session *session,
  * fetch 1 resource in this program, after reception of the response,
  * we submit GOAWAY and close the session.
  */
-static int on_stream_close_callback(nghttp2_session *session,
-                                    int32_t stream_id,
-                                    nghttp2_error_code error_code,
-                                    void *user_data)
-{
+static int on_stream_close_callback(nghttp2_session *session, int32_t stream_id,
+                                    uint32_t error_code _U_,
+                                    void *user_data _U_) {
   struct Request *req;
   req = nghttp2_session_get_stream_user_data(session, stream_id);
-  if(req) {
+  if (req) {
     int rv;
     rv = nghttp2_session_terminate_session(session, NGHTTP2_NO_ERROR);
 
-    if(rv != 0) {
+    if (rv != 0) {
       diec("nghttp2_session_terminate_session", rv);
     }
   }
@@ -286,16 +280,16 @@ static int on_stream_close_callback(nghttp2_session *session,
  * The implementation of nghttp2_on_data_chunk_recv_callback type. We
  * use this function to print the received response body.
  */
-static int on_data_chunk_recv_callback(nghttp2_session *session, uint8_t flags,
-                                       int32_t stream_id,
+static int on_data_chunk_recv_callback(nghttp2_session *session,
+                                       uint8_t flags _U_, int32_t stream_id,
                                        const uint8_t *data, size_t len,
-                                       void *user_data)
-{
+                                       void *user_data _U_) {
   struct Request *req;
   req = nghttp2_session_get_stream_user_data(session, stream_id);
-  if(req) {
+  if (req) {
     printf("[INFO] C <---------------------------- S (DATA chunk)\n"
-           "%lu bytes\n", (unsigned long int)len);
+           "%lu bytes\n",
+           (unsigned long int)len);
     fwrite(data, 1, len, stdout);
     printf("\n");
   }
@@ -308,23 +302,22 @@ static int on_data_chunk_recv_callback(nghttp2_session *session, uint8_t flags,
  * always required. Since we use nghttp2_session_recv(), the
  * recv_callback is also required.
  */
-static void setup_nghttp2_callbacks(nghttp2_session_callbacks *callbacks)
-{
+static void setup_nghttp2_callbacks(nghttp2_session_callbacks *callbacks) {
   nghttp2_session_callbacks_set_send_callback(callbacks, send_callback);
 
   nghttp2_session_callbacks_set_recv_callback(callbacks, recv_callback);
 
-  nghttp2_session_callbacks_set_on_frame_send_callback
-    (callbacks, on_frame_send_callback);
+  nghttp2_session_callbacks_set_on_frame_send_callback(callbacks,
+                                                       on_frame_send_callback);
 
-  nghttp2_session_callbacks_set_on_frame_recv_callback
-    (callbacks, on_frame_recv_callback);
+  nghttp2_session_callbacks_set_on_frame_recv_callback(callbacks,
+                                                       on_frame_recv_callback);
 
-  nghttp2_session_callbacks_set_on_stream_close_callback
-    (callbacks, on_stream_close_callback);
+  nghttp2_session_callbacks_set_on_stream_close_callback(
+      callbacks, on_stream_close_callback);
 
-  nghttp2_session_callbacks_set_on_data_chunk_recv_callback
-    (callbacks, on_data_chunk_recv_callback);
+  nghttp2_session_callbacks_set_on_data_chunk_recv_callback(
+      callbacks, on_data_chunk_recv_callback);
 }
 
 /*
@@ -332,16 +325,14 @@ static void setup_nghttp2_callbacks(nghttp2_session_callbacks *callbacks)
  * HTTP/2 protocol, if server does not offer HTTP/2 the nghttp2
  * library supports, we terminate program.
  */
-static int select_next_proto_cb(SSL* ssl,
-                                unsigned char **out, unsigned char *outlen,
-                                const unsigned char *in, unsigned int inlen,
-                                void *arg)
-{
+static int select_next_proto_cb(SSL *ssl _U_, unsigned char **out,
+                                unsigned char *outlen, const unsigned char *in,
+                                unsigned int inlen, void *arg _U_) {
   int rv;
   /* nghttp2_select_next_protocol() selects HTTP/2 protocol the
      nghttp2 library supports. */
   rv = nghttp2_select_next_protocol(out, outlen, in, inlen);
-  if(rv <= 0) {
+  if (rv <= 0) {
     die("Server did not advertise HTTP/2 protocol");
   }
   return SSL_TLSEXT_ERR_OK;
@@ -350,25 +341,23 @@ static int select_next_proto_cb(SSL* ssl,
 /*
  * Setup SSL/TLS context.
  */
-static void init_ssl_ctx(SSL_CTX *ssl_ctx)
-{
+static void init_ssl_ctx(SSL_CTX *ssl_ctx) {
   /* Disable SSLv2 and enable all workarounds for buggy servers */
-  SSL_CTX_set_options(ssl_ctx, SSL_OP_ALL|SSL_OP_NO_SSLv2);
+  SSL_CTX_set_options(ssl_ctx, SSL_OP_ALL | SSL_OP_NO_SSLv2);
   SSL_CTX_set_mode(ssl_ctx, SSL_MODE_AUTO_RETRY);
   SSL_CTX_set_mode(ssl_ctx, SSL_MODE_RELEASE_BUFFERS);
   /* Set NPN callback */
   SSL_CTX_set_next_proto_select_cb(ssl_ctx, select_next_proto_cb, NULL);
 }
 
-static void ssl_handshake(SSL *ssl, int fd)
-{
+static void ssl_handshake(SSL *ssl, int fd) {
   int rv;
-  if(SSL_set_fd(ssl, fd) == 0) {
+  if (SSL_set_fd(ssl, fd) == 0) {
     dief("SSL_set_fd", ERR_error_string(ERR_get_error(), NULL));
   }
   ERR_clear_error();
   rv = SSL_connect(ssl);
-  if(rv <= 0) {
+  if (rv <= 0) {
     dief("SSL_connect", ERR_error_string(ERR_get_error(), NULL));
   }
 }
@@ -377,8 +366,7 @@ static void ssl_handshake(SSL *ssl, int fd)
  * Connects to the host |host| and port |port|.  This function returns
  * the file descriptor of the client socket.
  */
-static int connect_to(const char *host, uint16_t port)
-{
+static int connect_to(const char *host, uint16_t port) {
   struct addrinfo hints;
   int fd = -1;
   int rv;
@@ -389,17 +377,18 @@ static int connect_to(const char *host, uint16_t port)
   hints.ai_family = AF_UNSPEC;
   hints.ai_socktype = SOCK_STREAM;
   rv = getaddrinfo(host, service, &hints, &res);
-  if(rv != 0) {
+  if (rv != 0) {
     dief("getaddrinfo", gai_strerror(rv));
   }
-  for(rp = res; rp; rp = rp->ai_next) {
+  for (rp = res; rp; rp = rp->ai_next) {
     fd = socket(rp->ai_family, rp->ai_socktype, rp->ai_protocol);
-    if(fd == -1) {
+    if (fd == -1) {
       continue;
     }
-    while((rv = connect(fd, rp->ai_addr, rp->ai_addrlen)) == -1 &&
-          errno == EINTR);
-    if(rv == 0) {
+    while ((rv = connect(fd, rp->ai_addr, rp->ai_addrlen)) == -1 &&
+           errno == EINTR)
+      ;
+    if (rv == 0) {
       break;
     }
     close(fd);
@@ -409,25 +398,25 @@ static int connect_to(const char *host, uint16_t port)
   return fd;
 }
 
-static void make_non_block(int fd)
-{
+static void make_non_block(int fd) {
   int flags, rv;
-  while((flags = fcntl(fd, F_GETFL, 0)) == -1 && errno == EINTR);
-  if(flags == -1) {
+  while ((flags = fcntl(fd, F_GETFL, 0)) == -1 && errno == EINTR)
+    ;
+  if (flags == -1) {
     dief("fcntl", strerror(errno));
   }
-  while((rv = fcntl(fd, F_SETFL, flags | O_NONBLOCK)) == -1 && errno == EINTR);
-  if(rv == -1) {
+  while ((rv = fcntl(fd, F_SETFL, flags | O_NONBLOCK)) == -1 && errno == EINTR)
+    ;
+  if (rv == -1) {
     dief("fcntl", strerror(errno));
   }
 }
 
-static void set_tcp_nodelay(int fd)
-{
+static void set_tcp_nodelay(int fd) {
   int val = 1;
   int rv;
   rv = setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, &val, (socklen_t)sizeof(val));
-  if(rv == -1) {
+  if (rv == -1) {
     dief("setsockopt", strerror(errno));
   }
 }
@@ -435,15 +424,14 @@ static void set_tcp_nodelay(int fd)
 /*
  * Update |pollfd| based on the state of |connection|.
  */
-static void ctl_poll(struct pollfd *pollfd, struct Connection *connection)
-{
+static void ctl_poll(struct pollfd *pollfd, struct Connection *connection) {
   pollfd->events = 0;
-  if(nghttp2_session_want_read(connection->session) ||
-     connection->want_io == WANT_READ) {
+  if (nghttp2_session_want_read(connection->session) ||
+      connection->want_io == WANT_READ) {
     pollfd->events |= POLLIN;
   }
-  if(nghttp2_session_want_write(connection->session) ||
-     connection->want_io == WANT_WRITE) {
+  if (nghttp2_session_want_write(connection->session) ||
+      connection->want_io == WANT_WRITE) {
     pollfd->events |= POLLOUT;
   }
 }
@@ -453,24 +441,20 @@ static void ctl_poll(struct pollfd *pollfd, struct Connection *connection)
  * function does not send packets; just append the request to the
  * internal queue in |connection->session|.
  */
-static void submit_request(struct Connection *connection, struct Request *req)
-{
+static void submit_request(struct Connection *connection, struct Request *req) {
   int32_t stream_id;
-  const nghttp2_nv nva[] = {
-    /* Make sure that the last item is NULL */
-    MAKE_NV(":method", "GET"),
-    MAKE_NV_CS(":path", req->path),
-    MAKE_NV(":scheme", "https"),
-    MAKE_NV_CS(":authority", req->hostport),
-    MAKE_NV("accept", "*/*"),
-    MAKE_NV("user-agent", "nghttp2/"NGHTTP2_VERSION)
-  };
+  /* Make sure that the last item is NULL */
+  const nghttp2_nv nva[] = {MAKE_NV(":method", "GET"),
+                            MAKE_NV_CS(":path", req->path),
+                            MAKE_NV(":scheme", "https"),
+                            MAKE_NV_CS(":authority", req->hostport),
+                            MAKE_NV("accept", "*/*"),
+                            MAKE_NV("user-agent", "nghttp2/" NGHTTP2_VERSION)};
 
-  stream_id = nghttp2_submit_request(connection->session, NULL,
-                                     nva, sizeof(nva)/sizeof(nva[0]),
-                                     NULL, req);
+  stream_id = nghttp2_submit_request(connection->session, NULL, nva,
+                                     sizeof(nva) / sizeof(nva[0]), NULL, req);
 
-  if(stream_id < 0) {
+  if (stream_id < 0) {
     diec("nghttp2_submit_request", stream_id);
   }
 
@@ -481,21 +465,19 @@ static void submit_request(struct Connection *connection, struct Request *req)
 /*
  * Performs the network I/O.
  */
-static void exec_io(struct Connection *connection)
-{
+static void exec_io(struct Connection *connection) {
   int rv;
   rv = nghttp2_session_recv(connection->session);
-  if(rv != 0) {
+  if (rv != 0) {
     diec("nghttp2_session_recv", rv);
   }
   rv = nghttp2_session_send(connection->session);
-  if(rv != 0) {
+  if (rv != 0) {
     diec("nghttp2_session_send", rv);
   }
 }
 
-static void request_init(struct Request *req, const struct URI *uri)
-{
+static void request_init(struct Request *req, const struct URI *uri) {
   req->host = strcopy(uri->host, uri->hostlen);
   req->port = uri->port;
   req->path = strcopy(uri->path, uri->pathlen);
@@ -503,8 +485,7 @@ static void request_init(struct Request *req, const struct URI *uri)
   req->stream_id = -1;
 }
 
-static void request_free(struct Request *req)
-{
+static void request_free(struct Request *req) {
   free(req->host);
   free(req->path);
   free(req->hostport);
@@ -513,8 +494,7 @@ static void request_free(struct Request *req)
 /*
  * Fetches the resource denoted by |uri|.
  */
-static void fetch_uri(const struct URI *uri)
-{
+static void fetch_uri(const struct URI *uri) {
   nghttp2_session_callbacks *callbacks;
   int fd;
   SSL_CTX *ssl_ctx;
@@ -529,16 +509,16 @@ static void fetch_uri(const struct URI *uri)
 
   /* Establish connection and setup SSL */
   fd = connect_to(req.host, req.port);
-  if(fd == -1) {
+  if (fd == -1) {
     die("Could not open file descriptor");
   }
   ssl_ctx = SSL_CTX_new(SSLv23_client_method());
-  if(ssl_ctx == NULL) {
+  if (ssl_ctx == NULL) {
     dief("SSL_CTX_new", ERR_error_string(ERR_get_error(), NULL));
   }
   init_ssl_ctx(ssl_ctx);
   ssl = SSL_new(ssl_ctx);
-  if(ssl == NULL) {
+  if (ssl == NULL) {
     dief("SSL_new", ERR_error_string(ERR_get_error(), NULL));
   }
   /* To simplify the program, we perform SSL/TLS handshake in blocking
@@ -560,18 +540,17 @@ static void fetch_uri(const struct URI *uri)
 
   rv = nghttp2_session_callbacks_new(&callbacks);
 
-  if(rv != 0) {
+  if (rv != 0) {
     diec("nghttp2_session_callbacks_new", rv);
   }
 
   setup_nghttp2_callbacks(callbacks);
 
-  rv = nghttp2_session_client_new(&connection.session, callbacks,
-                                  &connection);
+  rv = nghttp2_session_client_new(&connection.session, callbacks, &connection);
 
   nghttp2_session_callbacks_del(callbacks);
 
-  if(rv != 0) {
+  if (rv != 0) {
     diec("nghttp2_session_client_new", rv);
   }
 
@@ -582,16 +561,16 @@ static void fetch_uri(const struct URI *uri)
   ctl_poll(pollfds, &connection);
 
   /* Event loop */
-  while(nghttp2_session_want_read(connection.session) ||
-        nghttp2_session_want_write(connection.session)) {
+  while (nghttp2_session_want_read(connection.session) ||
+         nghttp2_session_want_write(connection.session)) {
     int nfds = poll(pollfds, npollfds, -1);
-    if(nfds == -1) {
+    if (nfds == -1) {
       dief("poll", strerror(errno));
     }
-    if(pollfds[0].revents & (POLLIN | POLLOUT)) {
+    if (pollfds[0].revents & (POLLIN | POLLOUT)) {
       exec_io(&connection);
     }
-    if((pollfds[0].revents & POLLHUP) || (pollfds[0].revents & POLLERR)) {
+    if ((pollfds[0].revents & POLLHUP) || (pollfds[0].revents & POLLERR)) {
       die("Connection error");
     }
     ctl_poll(pollfds, &connection);
@@ -607,96 +586,94 @@ static void fetch_uri(const struct URI *uri)
   request_free(&req);
 }
 
-static int parse_uri(struct URI *res, const char *uri)
-{
+static int parse_uri(struct URI *res, const char *uri) {
   /* We only interested in https */
   size_t len, i, offset;
   int ipv6addr = 0;
   memset(res, 0, sizeof(struct URI));
   len = strlen(uri);
-  if(len < 9 || memcmp("https://", uri, 8) != 0) {
+  if (len < 9 || memcmp("https://", uri, 8) != 0) {
     return -1;
   }
   offset = 8;
   res->host = res->hostport = &uri[offset];
   res->hostlen = 0;
-  if(uri[offset] == '[') {
+  if (uri[offset] == '[') {
     /* IPv6 literal address */
     ++offset;
     ++res->host;
     ipv6addr = 1;
-    for(i = offset; i < len; ++i) {
-      if(uri[i] == ']') {
-        res->hostlen = i-offset;
-        offset = i+1;
+    for (i = offset; i < len; ++i) {
+      if (uri[i] == ']') {
+        res->hostlen = i - offset;
+        offset = i + 1;
         break;
       }
     }
   } else {
     const char delims[] = ":/?#";
-    for(i = offset; i < len; ++i) {
-      if(strchr(delims, uri[i]) != NULL) {
+    for (i = offset; i < len; ++i) {
+      if (strchr(delims, uri[i]) != NULL) {
         break;
       }
     }
-    res->hostlen = i-offset;
+    res->hostlen = i - offset;
     offset = i;
   }
-  if(res->hostlen == 0) {
+  if (res->hostlen == 0) {
     return -1;
   }
   /* Assuming https */
   res->port = 443;
-  if(offset < len) {
-    if(uri[offset] == ':') {
+  if (offset < len) {
+    if (uri[offset] == ':') {
       /* port */
       const char delims[] = "/?#";
       int port = 0;
       ++offset;
-      for(i = offset; i < len; ++i) {
-        if(strchr(delims, uri[i]) != NULL) {
+      for (i = offset; i < len; ++i) {
+        if (strchr(delims, uri[i]) != NULL) {
           break;
         }
-        if('0' <= uri[i] && uri[i] <= '9') {
+        if ('0' <= uri[i] && uri[i] <= '9') {
           port *= 10;
-          port += uri[i]-'0';
-          if(port > 65535) {
+          port += uri[i] - '0';
+          if (port > 65535) {
             return -1;
           }
         } else {
           return -1;
         }
       }
-      if(port == 0) {
+      if (port == 0) {
         return -1;
       }
       offset = i;
       res->port = port;
     }
   }
-  res->hostportlen = uri+offset+ipv6addr-res->host;
-  for(i = offset; i < len; ++i) {
-    if(uri[i] == '#') {
+  res->hostportlen = uri + offset + ipv6addr - res->host;
+  for (i = offset; i < len; ++i) {
+    if (uri[i] == '#') {
       break;
     }
   }
-  if(i-offset == 0) {
+  if (i - offset == 0) {
     res->path = "/";
     res->pathlen = 1;
   } else {
     res->path = &uri[offset];
-    res->pathlen = i-offset;
+    res->pathlen = i - offset;
   }
   return 0;
 }
 
-int main(int argc, char **argv)
-{
+int main(int argc, char **argv) {
   struct URI uri;
   struct sigaction act;
   int rv;
 
-  if(argc < 2) {
+  if (argc < 2) {
     die("Specify a https URI");
   }
 
@@ -710,7 +687,7 @@ int main(int argc, char **argv)
   SSL_library_init();
 
   rv = parse_uri(&uri, argv[1]);
-  if(rv != 0) {
+  if (rv != 0) {
     die("parse_uri failed");
   }
   fetch_uri(&uri);
