@@ -22,6 +22,10 @@
  * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
  * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif /* !HAVE_CONFIG_H */
+
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netdb.h>
@@ -47,11 +51,13 @@
 
 #define OUTPUT_WOULDBLOCK_THRESHOLD (1 << 16)
 
-#define ARRLEN(x) (sizeof(x)/sizeof(x[0]))
+#define ARRLEN(x) (sizeof(x) / sizeof(x[0]))
 
-#define MAKE_NV(NAME, VALUE)                                            \
-  { (uint8_t*)NAME, (uint8_t*)VALUE, sizeof(NAME) - 1, sizeof(VALUE) - 1, \
-      NGHTTP2_NV_FLAG_NONE }
+#define MAKE_NV(NAME, VALUE)                                                   \
+  {                                                                            \
+    (uint8_t *) NAME, (uint8_t *)VALUE, sizeof(NAME) - 1, sizeof(VALUE) - 1,   \
+        NGHTTP2_NV_FLAG_NONE                                                   \
+  }
 
 struct app_context;
 typedef struct app_context app_context;
@@ -79,32 +85,40 @@ struct app_context {
 static unsigned char next_proto_list[256];
 static size_t next_proto_list_len;
 
-static int next_proto_cb(SSL *s, const unsigned char **data, unsigned int *len,
-                         void *arg)
-{
+static int next_proto_cb(SSL *s _U_, const unsigned char **data,
+                         unsigned int *len, void *arg _U_) {
   *data = next_proto_list;
   *len = (unsigned int)next_proto_list_len;
   return SSL_TLSEXT_ERR_OK;
 }
 
 /* Create SSL_CTX. */
-static SSL_CTX* create_ssl_ctx(const char *key_file, const char *cert_file)
-{
+static SSL_CTX *create_ssl_ctx(const char *key_file, const char *cert_file) {
   SSL_CTX *ssl_ctx;
+  EC_KEY *ecdh;
+
   ssl_ctx = SSL_CTX_new(SSLv23_server_method());
-  if(!ssl_ctx) {
+  if (!ssl_ctx) {
     errx(1, "Could not create SSL/TLS context: %s",
          ERR_error_string(ERR_get_error(), NULL));
   }
   SSL_CTX_set_options(ssl_ctx,
-                      SSL_OP_ALL | SSL_OP_NO_SSLv2 | SSL_OP_NO_COMPRESSION |
-                      SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION);
+                      SSL_OP_ALL | SSL_OP_NO_SSLv2 | SSL_OP_NO_SSLv3 |
+                          SSL_OP_NO_COMPRESSION |
+                          SSL_OP_NO_SESSION_RESUMPTION_ON_RENEGOTIATION);
 
-  if(SSL_CTX_use_PrivateKey_file(ssl_ctx, key_file,
-                                 SSL_FILETYPE_PEM) != 1) {
+  ecdh = EC_KEY_new_by_curve_name(NID_X9_62_prime256v1);
+  if (!ecdh) {
+    errx(1, "EC_KEY_new_by_curv_name failed: %s",
+         ERR_error_string(ERR_get_error(), NULL));
+  }
+  SSL_CTX_set_tmp_ecdh(ssl_ctx, ecdh);
+  EC_KEY_free(ecdh);
+
+  if (SSL_CTX_use_PrivateKey_file(ssl_ctx, key_file, SSL_FILETYPE_PEM) != 1) {
     errx(1, "Could not read private key file %s", key_file);
   }
-  if(SSL_CTX_use_certificate_chain_file(ssl_ctx, cert_file) != 1) {
+  if (SSL_CTX_use_certificate_chain_file(ssl_ctx, cert_file) != 1) {
     errx(1, "Could not read certificate file %s", cert_file);
   }
 
@@ -118,11 +132,10 @@ static SSL_CTX* create_ssl_ctx(const char *key_file, const char *cert_file)
 }
 
 /* Create SSL object */
-static SSL* create_ssl(SSL_CTX *ssl_ctx)
-{
+static SSL *create_ssl(SSL_CTX *ssl_ctx) {
   SSL *ssl;
   ssl = SSL_new(ssl_ctx);
-  if(!ssl) {
+  if (!ssl) {
     errx(1, "Could not create SSL/TLS session object: %s",
          ERR_error_string(ERR_get_error(), NULL));
   }
@@ -130,28 +143,25 @@ static SSL* create_ssl(SSL_CTX *ssl_ctx)
 }
 
 static void add_stream(http2_session_data *session_data,
-                       http2_stream_data *stream_data)
-{
+                       http2_stream_data *stream_data) {
   stream_data->next = session_data->root.next;
   session_data->root.next = stream_data;
   stream_data->prev = &session_data->root;
-  if(stream_data->next) {
+  if (stream_data->next) {
     stream_data->next->prev = stream_data;
   }
 }
 
-static void remove_stream(http2_session_data *session_data,
-                          http2_stream_data *stream_data)
-{
+static void remove_stream(http2_session_data *session_data _U_,
+                          http2_stream_data *stream_data) {
   stream_data->prev->next = stream_data->next;
-  if(stream_data->next) {
+  if (stream_data->next) {
     stream_data->next->prev = stream_data->prev;
   }
 }
 
-static http2_stream_data* create_http2_stream_data
-(http2_session_data *session_data, int32_t stream_id)
-{
+static http2_stream_data *
+create_http2_stream_data(http2_session_data *session_data, int32_t stream_id) {
   http2_stream_data *stream_data;
   stream_data = malloc(sizeof(http2_stream_data));
   memset(stream_data, 0, sizeof(http2_stream_data));
@@ -162,20 +172,18 @@ static http2_stream_data* create_http2_stream_data
   return stream_data;
 }
 
-static void delete_http2_stream_data(http2_stream_data *stream_data)
-{
-  if(stream_data->fd != -1) {
+static void delete_http2_stream_data(http2_stream_data *stream_data) {
+  if (stream_data->fd != -1) {
     close(stream_data->fd);
   }
   free(stream_data->request_path);
   free(stream_data);
 }
 
-static http2_session_data* create_http2_session_data(app_context *app_ctx,
+static http2_session_data *create_http2_session_data(app_context *app_ctx,
                                                      int fd,
                                                      struct sockaddr *addr,
-                                                     int addrlen)
-{
+                                                     int addrlen) {
   int rv;
   http2_session_data *session_data;
   SSL *ssl;
@@ -187,12 +195,11 @@ static http2_session_data* create_http2_session_data(app_context *app_ctx,
   memset(session_data, 0, sizeof(http2_session_data));
   session_data->app_ctx = app_ctx;
   setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, (char *)&val, sizeof(val));
-  session_data->bev = bufferevent_openssl_socket_new
-    (app_ctx->evbase, fd, ssl,
-     BUFFEREVENT_SSL_ACCEPTING,
-     BEV_OPT_CLOSE_ON_FREE | BEV_OPT_DEFER_CALLBACKS);
+  session_data->bev = bufferevent_openssl_socket_new(
+      app_ctx->evbase, fd, ssl, BUFFEREVENT_SSL_ACCEPTING,
+      BEV_OPT_CLOSE_ON_FREE | BEV_OPT_DEFER_CALLBACKS);
   rv = getnameinfo(addr, addrlen, host, sizeof(host), NULL, 0, NI_NUMERICHOST);
-  if(rv != 0) {
+  if (rv != 0) {
     session_data->client_addr = strdup("(unknown)");
   } else {
     session_data->client_addr = strdup(host);
@@ -201,17 +208,16 @@ static http2_session_data* create_http2_session_data(app_context *app_ctx,
   return session_data;
 }
 
-static void delete_http2_session_data(http2_session_data *session_data)
-{
+static void delete_http2_session_data(http2_session_data *session_data) {
   http2_stream_data *stream_data;
   SSL *ssl = bufferevent_openssl_get_ssl(session_data->bev);
   fprintf(stderr, "%s disconnected\n", session_data->client_addr);
-  if(ssl) {
+  if (ssl) {
     SSL_shutdown(ssl);
   }
   bufferevent_free(session_data->bev);
   nghttp2_session_del(session_data->session);
-  for(stream_data = session_data->root.next; stream_data;) {
+  for (stream_data = session_data->root.next; stream_data;) {
     http2_stream_data *next = stream_data->next;
     delete_http2_stream_data(stream_data);
     stream_data = next;
@@ -222,11 +228,10 @@ static void delete_http2_session_data(http2_session_data *session_data)
 
 /* Serialize the frame and send (or buffer) the data to
    bufferevent. */
-static int session_send(http2_session_data *session_data)
-{
+static int session_send(http2_session_data *session_data) {
   int rv;
   rv = nghttp2_session_send(session_data->session);
-  if(rv != 0) {
+  if (rv != 0) {
     warnx("Fatal error: %s", nghttp2_strerror(rv));
     return -1;
   }
@@ -237,37 +242,34 @@ static int session_send(http2_session_data *session_data)
    function. Invocation of nghttp2_session_mem_recv() may make
    additional pending frames, so call session_send() at the end of the
    function. */
-static int session_recv(http2_session_data *session_data)
-{
+static int session_recv(http2_session_data *session_data) {
   ssize_t readlen;
   struct evbuffer *input = bufferevent_get_input(session_data->bev);
   size_t datalen = evbuffer_get_length(input);
   unsigned char *data = evbuffer_pullup(input, -1);
 
   readlen = nghttp2_session_mem_recv(session_data->session, data, datalen);
-  if(readlen < 0) {
+  if (readlen < 0) {
     warnx("Fatal error: %s", nghttp2_strerror((int)readlen));
     return -1;
   }
-  if(evbuffer_drain(input, readlen) != 0) {
+  if (evbuffer_drain(input, readlen) != 0) {
     warnx("Fatal error: evbuffer_drain failed");
     return -1;
   }
-  if(session_send(session_data) != 0) {
+  if (session_send(session_data) != 0) {
     return -1;
   }
   return 0;
 }
 
-static ssize_t send_callback(nghttp2_session *session,
-                             const uint8_t *data, size_t length,
-                             int flags, void *user_data)
-{
-  http2_session_data *session_data = (http2_session_data*)user_data;
+static ssize_t send_callback(nghttp2_session *session _U_, const uint8_t *data,
+                             size_t length, int flags _U_, void *user_data) {
+  http2_session_data *session_data = (http2_session_data *)user_data;
   struct bufferevent *bev = session_data->bev;
   /* Avoid excessive buffering in server side. */
-  if(evbuffer_get_length(bufferevent_get_output(session_data->bev)) >=
-     OUTPUT_WOULDBLOCK_THRESHOLD) {
+  if (evbuffer_get_length(bufferevent_get_output(session_data->bev)) >=
+      OUTPUT_WOULDBLOCK_THRESHOLD) {
     return NGHTTP2_ERR_WOULDBLOCK;
   }
   bufferevent_write(bev, data, length);
@@ -275,26 +277,24 @@ static ssize_t send_callback(nghttp2_session *session,
 }
 
 /* Returns nonzero if the string |s| ends with the substring |sub| */
-static int ends_with(const char *s, const char *sub)
-{
+static int ends_with(const char *s, const char *sub) {
   size_t slen = strlen(s);
   size_t sublen = strlen(sub);
-  if(slen < sublen) {
+  if (slen < sublen) {
     return 0;
   }
   return memcmp(s + slen - sublen, sub, sublen) == 0;
 }
 
 /* Returns int value of hex string character |c| */
-static uint8_t hex_to_uint(uint8_t c)
-{
-  if('0' <= c && c <= '9') {
+static uint8_t hex_to_uint(uint8_t c) {
+  if ('0' <= c && c <= '9') {
     return c - '0';
   }
-  if('A' <= c && c <= 'F') {
+  if ('A' <= c && c <= 'F') {
     return c - 'A' + 10;
   }
-  if('a' <= c && c <= 'f') {
+  if ('a' <= c && c <= 'f') {
     return c - 'a' + 10;
   }
   return 0;
@@ -304,16 +304,15 @@ static uint8_t hex_to_uint(uint8_t c)
    and returns the decoded byte string in allocated buffer. The return
    value is NULL terminated. The caller must free the returned
    string. */
-static char* percent_decode(const uint8_t *value, size_t valuelen)
-{
+static char *percent_decode(const uint8_t *value, size_t valuelen) {
   char *res;
 
   res = malloc(valuelen + 1);
-  if(valuelen > 3) {
+  if (valuelen > 3) {
     size_t i, j;
-    for(i = 0, j = 0; i < valuelen - 2;) {
-      if(value[i] != '%' ||
-         !isxdigit(value[i + 1]) || !isxdigit(value[i + 2])) {
+    for (i = 0, j = 0; i < valuelen - 2;) {
+      if (value[i] != '%' || !isxdigit(value[i + 1]) ||
+          !isxdigit(value[i + 2])) {
         res[j++] = value[i++];
         continue;
       }
@@ -329,33 +328,33 @@ static char* percent_decode(const uint8_t *value, size_t valuelen)
   return res;
 }
 
-static ssize_t file_read_callback
-(nghttp2_session *session, int32_t stream_id,
- uint8_t *buf, size_t length, uint32_t *data_flags,
- nghttp2_data_source *source, void *user_data)
-{
+static ssize_t file_read_callback(nghttp2_session *session _U_,
+                                  int32_t stream_id _U_, uint8_t *buf,
+                                  size_t length, uint32_t *data_flags,
+                                  nghttp2_data_source *source,
+                                  void *user_data _U_) {
   int fd = source->fd;
   ssize_t r;
-  while((r = read(fd, buf, length)) == -1 && errno == EINTR);
-  if(r == -1) {
+  while ((r = read(fd, buf, length)) == -1 && errno == EINTR)
+    ;
+  if (r == -1) {
     return NGHTTP2_ERR_TEMPORAL_CALLBACK_FAILURE;
   }
-  if(r == 0) {
+  if (r == 0) {
     *data_flags |= NGHTTP2_DATA_FLAG_EOF;
   }
   return r;
 }
 
 static int send_response(nghttp2_session *session, int32_t stream_id,
-                         nghttp2_nv *nva, size_t nvlen, int fd)
-{
+                         nghttp2_nv *nva, size_t nvlen, int fd) {
   int rv;
   nghttp2_data_provider data_prd;
   data_prd.source.fd = fd;
   data_prd.read_callback = file_read_callback;
 
   rv = nghttp2_submit_response(session, stream_id, nva, nvlen, &data_prd);
-  if(rv != 0) {
+  if (rv != 0) {
     warnx("Fatal error: %s", nghttp2_strerror(rv));
     return -1;
   }
@@ -363,25 +362,22 @@ static int send_response(nghttp2_session *session, int32_t stream_id,
 }
 
 const char ERROR_HTML[] = "<html><head><title>404</title></head>"
-  "<body><h1>404 Not Found</h1></body></html>";
+                          "<body><h1>404 Not Found</h1></body></html>";
 
 static int error_reply(nghttp2_session *session,
-                       http2_stream_data *stream_data)
-{
+                       http2_stream_data *stream_data) {
   int rv;
   ssize_t writelen;
   int pipefd[2];
-  nghttp2_nv hdrs[] = {
-    MAKE_NV(":status", "404")
-  };
+  nghttp2_nv hdrs[] = {MAKE_NV(":status", "404")};
 
   rv = pipe(pipefd);
-  if(rv != 0) {
+  if (rv != 0) {
     warn("Could not create pipe");
     rv = nghttp2_submit_rst_stream(session, NGHTTP2_FLAG_NONE,
                                    stream_data->stream_id,
                                    NGHTTP2_INTERNAL_ERROR);
-    if(rv != 0) {
+    if (rv != 0) {
       warnx("Fatal error: %s", nghttp2_strerror(rv));
       return -1;
     }
@@ -391,15 +387,15 @@ static int error_reply(nghttp2_session *session,
   writelen = write(pipefd[1], ERROR_HTML, sizeof(ERROR_HTML) - 1);
   close(pipefd[1]);
 
-  if(writelen != sizeof(ERROR_HTML) - 1) {
+  if (writelen != sizeof(ERROR_HTML) - 1) {
     close(pipefd[0]);
     return -1;
   }
 
   stream_data->fd = pipefd[0];
 
-  if(send_response(session, stream_data->stream_id, hdrs, ARRLEN(hdrs),
-                   pipefd[0]) != 0) {
+  if (send_response(session, stream_data->stream_id, hdrs, ARRLEN(hdrs),
+                    pipefd[0]) != 0) {
     close(pipefd[0]);
     return -1;
   }
@@ -409,27 +405,26 @@ static int error_reply(nghttp2_session *session,
 /* nghttp2_on_header_callback: Called when nghttp2 library emits
    single header name/value pair. */
 static int on_header_callback(nghttp2_session *session,
-                              const nghttp2_frame *frame,
-                              const uint8_t *name, size_t namelen,
-                              const uint8_t *value, size_t valuelen,
-                              uint8_t flags,
-                              void *user_data)
-{
+                              const nghttp2_frame *frame, const uint8_t *name,
+                              size_t namelen, const uint8_t *value,
+                              size_t valuelen, uint8_t flags _U_,
+                              void *user_data _U_) {
   http2_stream_data *stream_data;
   const char PATH[] = ":path";
-  switch(frame->hd.type) {
+  switch (frame->hd.type) {
   case NGHTTP2_HEADERS:
-    if(frame->headers.cat != NGHTTP2_HCAT_REQUEST) {
+    if (frame->headers.cat != NGHTTP2_HCAT_REQUEST) {
       break;
     }
-    stream_data = nghttp2_session_get_stream_user_data(session,
-                                                       frame->hd.stream_id);
-    if(!stream_data || stream_data->request_path) {
+    stream_data =
+        nghttp2_session_get_stream_user_data(session, frame->hd.stream_id);
+    if (!stream_data || stream_data->request_path) {
       break;
     }
-    if(namelen == sizeof(PATH) - 1 && memcmp(PATH, name, namelen) == 0) {
+    if (namelen == sizeof(PATH) - 1 && memcmp(PATH, name, namelen) == 0) {
       size_t j;
-      for(j = 0; j < valuelen && value[j] != '?'; ++j);
+      for (j = 0; j < valuelen && value[j] != '?'; ++j)
+        ;
       stream_data->request_path = percent_decode(value, j);
     }
     break;
@@ -439,13 +434,12 @@ static int on_header_callback(nghttp2_session *session,
 
 static int on_begin_headers_callback(nghttp2_session *session,
                                      const nghttp2_frame *frame,
-                                     void *user_data)
-{
-  http2_session_data *session_data = (http2_session_data*)user_data;
+                                     void *user_data) {
+  http2_session_data *session_data = (http2_session_data *)user_data;
   http2_stream_data *stream_data;
 
-  if(frame->hd.type != NGHTTP2_HEADERS ||
-     frame->headers.cat != NGHTTP2_HCAT_REQUEST) {
+  if (frame->hd.type != NGHTTP2_HEADERS ||
+      frame->headers.cat != NGHTTP2_HCAT_REQUEST) {
     return 0;
   }
   stream_data = create_http2_stream_data(session_data, frame->hd.stream_id);
@@ -456,52 +450,47 @@ static int on_begin_headers_callback(nghttp2_session *session,
 
 /* Minimum check for directory traversal. Returns nonzero if it is
    safe. */
-static int check_path(const char *path)
-{
+static int check_path(const char *path) {
   /* We don't like '\' in url. */
-  return path[0] && path[0] == '/' &&
-    strchr(path, '\\') == NULL &&
-    strstr(path, "/../") == NULL &&
-    strstr(path, "/./") == NULL &&
-    !ends_with(path, "/..") && !ends_with(path, "/.");
+  return path[0] && path[0] == '/' && strchr(path, '\\') == NULL &&
+         strstr(path, "/../") == NULL && strstr(path, "/./") == NULL &&
+         !ends_with(path, "/..") && !ends_with(path, "/.");
 }
 
 static int on_request_recv(nghttp2_session *session,
                            http2_session_data *session_data,
-                           http2_stream_data *stream_data)
-{
+                           http2_stream_data *stream_data) {
   int fd;
-  nghttp2_nv hdrs[] = {
-    MAKE_NV(":status", "200")
-  };
+  nghttp2_nv hdrs[] = {MAKE_NV(":status", "200")};
   char *rel_path;
 
-  if(!stream_data->request_path) {
-    if(error_reply(session, stream_data) != 0) {
+  if (!stream_data->request_path) {
+    if (error_reply(session, stream_data) != 0) {
       return NGHTTP2_ERR_CALLBACK_FAILURE;
     }
     return 0;
   }
   fprintf(stderr, "%s GET %s\n", session_data->client_addr,
           stream_data->request_path);
-  if(!check_path(stream_data->request_path)) {
-    if(error_reply(session, stream_data) != 0) {
+  if (!check_path(stream_data->request_path)) {
+    if (error_reply(session, stream_data) != 0) {
       return NGHTTP2_ERR_CALLBACK_FAILURE;
     }
     return 0;
   }
-  for(rel_path = stream_data->request_path; *rel_path == '/'; ++rel_path);
+  for (rel_path = stream_data->request_path; *rel_path == '/'; ++rel_path)
+    ;
   fd = open(rel_path, O_RDONLY);
-  if(fd == -1) {
-    if(error_reply(session, stream_data) != 0) {
+  if (fd == -1) {
+    if (error_reply(session, stream_data) != 0) {
       return NGHTTP2_ERR_CALLBACK_FAILURE;
     }
     return 0;
   }
   stream_data->fd = fd;
 
-  if(send_response(session, stream_data->stream_id, hdrs,
-                   ARRLEN(hdrs), fd) != 0) {
+  if (send_response(session, stream_data->stream_id, hdrs, ARRLEN(hdrs), fd) !=
+      0) {
     close(fd);
     return NGHTTP2_ERR_CALLBACK_FAILURE;
   }
@@ -509,20 +498,19 @@ static int on_request_recv(nghttp2_session *session,
 }
 
 static int on_frame_recv_callback(nghttp2_session *session,
-                                  const nghttp2_frame *frame, void *user_data)
-{
-  http2_session_data *session_data = (http2_session_data*)user_data;
+                                  const nghttp2_frame *frame, void *user_data) {
+  http2_session_data *session_data = (http2_session_data *)user_data;
   http2_stream_data *stream_data;
-  switch(frame->hd.type) {
+  switch (frame->hd.type) {
   case NGHTTP2_DATA:
   case NGHTTP2_HEADERS:
     /* Check that the client request has finished */
-    if(frame->hd.flags & NGHTTP2_FLAG_END_STREAM) {
-      stream_data = nghttp2_session_get_stream_user_data(session,
-                                                         frame->hd.stream_id);
+    if (frame->hd.flags & NGHTTP2_FLAG_END_STREAM) {
+      stream_data =
+          nghttp2_session_get_stream_user_data(session, frame->hd.stream_id);
       /* For DATA and HEADERS frame, this callback may be called after
          on_stream_close_callback. Check that stream still alive. */
-      if(!stream_data) {
+      if (!stream_data) {
         return 0;
       }
       return on_request_recv(session, session_data, stream_data);
@@ -534,16 +522,13 @@ static int on_frame_recv_callback(nghttp2_session *session,
   return 0;
 }
 
-static int on_stream_close_callback(nghttp2_session *session,
-                                    int32_t stream_id,
-                                    nghttp2_error_code error_code,
-                                    void *user_data)
-{
-  http2_session_data *session_data = (http2_session_data*)user_data;
+static int on_stream_close_callback(nghttp2_session *session, int32_t stream_id,
+                                    uint32_t error_code _U_, void *user_data) {
+  http2_session_data *session_data = (http2_session_data *)user_data;
   http2_stream_data *stream_data;
 
   stream_data = nghttp2_session_get_stream_user_data(session, stream_id);
-  if(!stream_data) {
+  if (!stream_data) {
     return 0;
   }
   remove_stream(session_data, stream_data);
@@ -551,8 +536,7 @@ static int on_stream_close_callback(nghttp2_session *session,
   return 0;
 }
 
-static void initialize_nghttp2_session(http2_session_data *session_data)
-{
+static void initialize_nghttp2_session(http2_session_data *session_data) {
   nghttp2_option *option;
   nghttp2_session_callbacks *callbacks;
 
@@ -566,19 +550,17 @@ static void initialize_nghttp2_session(http2_session_data *session_data)
 
   nghttp2_session_callbacks_set_send_callback(callbacks, send_callback);
 
-  nghttp2_session_callbacks_set_on_frame_recv_callback
-    (callbacks, on_frame_recv_callback);
+  nghttp2_session_callbacks_set_on_frame_recv_callback(callbacks,
+                                                       on_frame_recv_callback);
 
-  nghttp2_session_callbacks_set_on_stream_close_callback
-    (callbacks, on_stream_close_callback);
-
-  nghttp2_session_callbacks_set_on_header_callback
-    (callbacks, on_header_callback);
-
-  nghttp2_session_callbacks_set_on_begin_headers_callback
-    (callbacks, on_begin_headers_callback);
+  nghttp2_session_callbacks_set_on_stream_close_callback(
+      callbacks, on_stream_close_callback);
 
+  nghttp2_session_callbacks_set_on_header_callback(callbacks,
+                                                   on_header_callback);
 
+  nghttp2_session_callbacks_set_on_begin_headers_callback(
+      callbacks, on_begin_headers_callback);
 
   nghttp2_session_server_new2(&session_data->session, callbacks, session_data,
                               option);
@@ -589,16 +571,14 @@ static void initialize_nghttp2_session(http2_session_data *session_data)
 
 /* Send HTTP/2 client connection header, which includes 24 bytes
    magic octets and SETTINGS frame */
-static int send_server_connection_header(http2_session_data *session_data)
-{
+static int send_server_connection_header(http2_session_data *session_data) {
   nghttp2_settings_entry iv[1] = {
-    { NGHTTP2_SETTINGS_MAX_CONCURRENT_STREAMS, 100 }
-  };
+      {NGHTTP2_SETTINGS_MAX_CONCURRENT_STREAMS, 100}};
   int rv;
 
-  rv = nghttp2_submit_settings(session_data->session, NGHTTP2_FLAG_NONE,
-                               iv, ARRLEN(iv));
-  if(rv != 0) {
+  rv = nghttp2_submit_settings(session_data->session, NGHTTP2_FLAG_NONE, iv,
+                               ARRLEN(iv));
+  if (rv != 0) {
     warnx("Fatal error: %s", nghttp2_strerror(rv));
     return -1;
   }
@@ -607,10 +587,9 @@ static int send_server_connection_header(http2_session_data *session_data)
 
 /* readcb for bufferevent after client connection header was
    checked. */
-static void readcb(struct bufferevent *bev, void *ptr)
-{
-  http2_session_data *session_data = (http2_session_data*)ptr;
-  if(session_recv(session_data) != 0) {
+static void readcb(struct bufferevent *bev _U_, void *ptr) {
+  http2_session_data *session_data = (http2_session_data *)ptr;
+  if (session_recv(session_data) != 0) {
     delete_http2_session_data(session_data);
     return;
   }
@@ -624,54 +603,51 @@ static void readcb(struct bufferevent *bev, void *ptr)
    process pending data in the output buffer. This is necessary
    because we have a threshold on the buffer size to avoid too much
    buffering. See send_callback(). */
-static void writecb(struct bufferevent *bev, void *ptr)
-{
-  http2_session_data *session_data = (http2_session_data*)ptr;
-  if(evbuffer_get_length(bufferevent_get_output(bev)) > 0) {
+static void writecb(struct bufferevent *bev, void *ptr) {
+  http2_session_data *session_data = (http2_session_data *)ptr;
+  if (evbuffer_get_length(bufferevent_get_output(bev)) > 0) {
     return;
   }
-  if(nghttp2_session_want_read(session_data->session) == 0 &&
-     nghttp2_session_want_write(session_data->session) == 0) {
+  if (nghttp2_session_want_read(session_data->session) == 0 &&
+      nghttp2_session_want_write(session_data->session) == 0) {
     delete_http2_session_data(session_data);
     return;
   }
-  if(session_send(session_data) != 0) {
+  if (session_send(session_data) != 0) {
     delete_http2_session_data(session_data);
     return;
   }
 }
 
 /* eventcb for bufferevent */
-static void eventcb(struct bufferevent *bev, short events, void *ptr)
-{
-  http2_session_data *session_data = (http2_session_data*)ptr;
-  if(events & BEV_EVENT_CONNECTED) {
+static void eventcb(struct bufferevent *bev _U_, short events, void *ptr) {
+  http2_session_data *session_data = (http2_session_data *)ptr;
+  if (events & BEV_EVENT_CONNECTED) {
     fprintf(stderr, "%s connected\n", session_data->client_addr);
 
     initialize_nghttp2_session(session_data);
 
-    if(send_server_connection_header(session_data) != 0) {
+    if (send_server_connection_header(session_data) != 0) {
       delete_http2_session_data(session_data);
       return;
     }
 
     return;
   }
-  if(events & BEV_EVENT_EOF) {
+  if (events & BEV_EVENT_EOF) {
     fprintf(stderr, "%s EOF\n", session_data->client_addr);
-  } else if(events & BEV_EVENT_ERROR) {
+  } else if (events & BEV_EVENT_ERROR) {
     fprintf(stderr, "%s network error\n", session_data->client_addr);
-  } else if(events & BEV_EVENT_TIMEOUT) {
+  } else if (events & BEV_EVENT_TIMEOUT) {
     fprintf(stderr, "%s timeout\n", session_data->client_addr);
   }
   delete_http2_session_data(session_data);
 }
 
 /* callback for evconnlistener */
-static void acceptcb(struct evconnlistener *listener, int fd,
-                     struct sockaddr *addr, int addrlen, void *arg)
-{
-  app_context *app_ctx = (app_context*)arg;
+static void acceptcb(struct evconnlistener *listener _U_, int fd,
+                     struct sockaddr *addr, int addrlen, void *arg) {
+  app_context *app_ctx = (app_context *)arg;
   http2_session_data *session_data;
 
   session_data = create_http2_session_data(app_ctx, fd, addr, addrlen);
@@ -680,8 +656,7 @@ static void acceptcb(struct evconnlistener *listener, int fd,
 }
 
 static void start_listen(struct event_base *evbase, const char *service,
-                         app_context *app_ctx)
-{
+                         app_context *app_ctx) {
   int rv;
   struct addrinfo hints;
   struct addrinfo *res, *rp;
@@ -695,16 +670,15 @@ static void start_listen(struct event_base *evbase, const char *service,
 #endif /* AI_ADDRCONFIG */
 
   rv = getaddrinfo(NULL, service, &hints, &res);
-  if(rv != 0) {
+  if (rv != 0) {
     errx(1, NULL);
   }
-  for(rp = res; rp; rp = rp->ai_next) {
+  for (rp = res; rp; rp = rp->ai_next) {
     struct evconnlistener *listener;
-    listener = evconnlistener_new_bind(evbase, acceptcb, app_ctx,
-                                       LEV_OPT_CLOSE_ON_FREE |
-                                       LEV_OPT_REUSEABLE, 16,
-                                       rp->ai_addr, rp->ai_addrlen);
-    if(listener) {
+    listener = evconnlistener_new_bind(
+        evbase, acceptcb, app_ctx, LEV_OPT_CLOSE_ON_FREE | LEV_OPT_REUSEABLE,
+        16, rp->ai_addr, rp->ai_addrlen);
+    if (listener) {
       freeaddrinfo(res);
 
       return;
@@ -714,16 +688,14 @@ static void start_listen(struct event_base *evbase, const char *service,
 }
 
 static void initialize_app_context(app_context *app_ctx, SSL_CTX *ssl_ctx,
-                                   struct event_base *evbase)
-{
+                                   struct event_base *evbase) {
   memset(app_ctx, 0, sizeof(app_context));
   app_ctx->ssl_ctx = ssl_ctx;
   app_ctx->evbase = evbase;
 }
 
-static void run(const char *service,
-                const char *key_file, const char *cert_file)
-{
+static void run(const char *service, const char *key_file,
+                const char *cert_file) {
   SSL_CTX *ssl_ctx;
   app_context app_ctx;
   struct event_base *evbase;
@@ -739,11 +711,10 @@ static void run(const char *service,
   SSL_CTX_free(ssl_ctx);
 }
 
-int main(int argc, char **argv)
-{
+int main(int argc, char **argv) {
   struct sigaction act;
 
-  if(argc < 4) {
+  if (argc < 4) {
     fprintf(stderr, "Usage: libevent-server PORT KEY_FILE CERT_FILE\n");
     exit(EXIT_FAILURE);
   }
