@@ -28,8 +28,7 @@
 
 #include "nghttp2_helper.h"
 
-void nghttp2_buf_init(nghttp2_buf *buf)
-{
+void nghttp2_buf_init(nghttp2_buf *buf) {
   buf->begin = NULL;
   buf->end = NULL;
   buf->pos = NULL;
@@ -37,15 +36,13 @@ void nghttp2_buf_init(nghttp2_buf *buf)
   buf->mark = NULL;
 }
 
-int nghttp2_buf_init2(nghttp2_buf *buf, size_t initial)
-{
+int nghttp2_buf_init2(nghttp2_buf *buf, size_t initial) {
   nghttp2_buf_init(buf);
   return nghttp2_buf_reserve(buf, initial);
 }
 
-void nghttp2_buf_free(nghttp2_buf *buf)
-{
-  if(buf == NULL) {
+void nghttp2_buf_free(nghttp2_buf *buf) {
+  if (buf == NULL) {
     return;
   }
 
@@ -53,21 +50,20 @@ void nghttp2_buf_free(nghttp2_buf *buf)
   buf->begin = NULL;
 }
 
-int nghttp2_buf_reserve(nghttp2_buf *buf, size_t new_cap)
-{
+int nghttp2_buf_reserve(nghttp2_buf *buf, size_t new_cap) {
   uint8_t *ptr;
   size_t cap;
 
   cap = nghttp2_buf_cap(buf);
 
-  if(cap >= new_cap) {
+  if (cap >= new_cap) {
     return 0;
   }
 
   new_cap = nghttp2_max(new_cap, cap * 2);
 
   ptr = realloc(buf->begin, new_cap);
-  if(ptr == NULL) {
+  if (ptr == NULL) {
     return NGHTTP2_ERR_NOMEM;
   }
 
@@ -80,40 +76,27 @@ int nghttp2_buf_reserve(nghttp2_buf *buf, size_t new_cap)
   return 0;
 }
 
-int nghttp2_buf_pos_reserve(nghttp2_buf *buf, size_t new_rel_cap)
-{
-  return nghttp2_buf_reserve(buf, nghttp2_buf_pos_offset(buf) + new_rel_cap);
-}
-
-int nghttp2_buf_last_reserve(nghttp2_buf *buf, size_t new_rel_cap)
-{
-  return nghttp2_buf_reserve(buf, nghttp2_buf_last_offset(buf) + new_rel_cap);
-}
-
-void nghttp2_buf_reset(nghttp2_buf *buf)
-{
+void nghttp2_buf_reset(nghttp2_buf *buf) {
   buf->pos = buf->last = buf->mark = buf->begin;
 }
 
-void nghttp2_buf_wrap_init(nghttp2_buf *buf, uint8_t *begin, size_t len)
-{
+void nghttp2_buf_wrap_init(nghttp2_buf *buf, uint8_t *begin, size_t len) {
   buf->begin = buf->pos = buf->last = buf->mark = begin;
   buf->end = begin + len;
 }
 
-static int buf_chain_new(nghttp2_buf_chain **chain, size_t chunk_length)
-{
+static int buf_chain_new(nghttp2_buf_chain **chain, size_t chunk_length) {
   int rv;
 
   *chain = malloc(sizeof(nghttp2_buf_chain));
-  if(*chain == NULL) {
+  if (*chain == NULL) {
     return NGHTTP2_ERR_NOMEM;
   }
 
   (*chain)->next = NULL;
 
   rv = nghttp2_buf_init2(&(*chain)->buf, chunk_length);
-  if(rv != 0) {
+  if (rv != 0) {
     free(*chain);
     return NGHTTP2_ERR_NOMEM;
   }
@@ -121,36 +104,32 @@ static int buf_chain_new(nghttp2_buf_chain **chain, size_t chunk_length)
   return 0;
 }
 
-static void buf_chain_del(nghttp2_buf_chain *chain)
-{
+static void buf_chain_del(nghttp2_buf_chain *chain) {
   nghttp2_buf_free(&chain->buf);
   free(chain);
 }
 
 int nghttp2_bufs_init(nghttp2_bufs *bufs, size_t chunk_length,
-                      size_t max_chunk)
-{
+                      size_t max_chunk) {
   return nghttp2_bufs_init2(bufs, chunk_length, max_chunk, 0);
 }
 
 int nghttp2_bufs_init2(nghttp2_bufs *bufs, size_t chunk_length,
-                       size_t max_chunk, size_t offset)
-{
+                       size_t max_chunk, size_t offset) {
   return nghttp2_bufs_init3(bufs, chunk_length, max_chunk, max_chunk, offset);
 }
 
 int nghttp2_bufs_init3(nghttp2_bufs *bufs, size_t chunk_length,
-                       size_t max_chunk, size_t chunk_keep, size_t offset)
-{
+                       size_t max_chunk, size_t chunk_keep, size_t offset) {
   int rv;
   nghttp2_buf_chain *chain;
 
-  if(chunk_keep == 0 || max_chunk < chunk_keep || chunk_length < offset) {
+  if (chunk_keep == 0 || max_chunk < chunk_keep || chunk_length < offset) {
     return NGHTTP2_ERR_INVALID_ARGUMENT;
   }
 
   rv = buf_chain_new(&chain, chunk_length);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
 
@@ -169,17 +148,16 @@ int nghttp2_bufs_init3(nghttp2_bufs *bufs, size_t chunk_length,
   return 0;
 }
 
-int nghttp2_bufs_realloc(nghttp2_bufs *bufs, size_t chunk_length)
-{
+int nghttp2_bufs_realloc(nghttp2_bufs *bufs, size_t chunk_length) {
   int rv;
   nghttp2_buf_chain *chain;
 
-  if(chunk_length < bufs->offset) {
+  if (chunk_length < bufs->offset) {
     return NGHTTP2_ERR_INVALID_ARGUMENT;
   }
 
   rv = buf_chain_new(&chain, chunk_length);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
 
@@ -196,15 +174,14 @@ int nghttp2_bufs_realloc(nghttp2_bufs *bufs, size_t chunk_length)
   return 0;
 }
 
-void nghttp2_bufs_free(nghttp2_bufs *bufs)
-{
+void nghttp2_bufs_free(nghttp2_bufs *bufs) {
   nghttp2_buf_chain *chain, *next_chain;
 
-  if(bufs == NULL) {
+  if (bufs == NULL) {
     return;
   }
 
-  for(chain = bufs->head; chain;) {
+  for (chain = bufs->head; chain;) {
     next_chain = chain->next;
 
     buf_chain_del(chain);
@@ -215,12 +192,11 @@ void nghttp2_bufs_free(nghttp2_bufs *bufs)
   bufs->head = NULL;
 }
 
-int nghttp2_bufs_wrap_init(nghttp2_bufs *bufs, uint8_t *begin, size_t len)
-{
+int nghttp2_bufs_wrap_init(nghttp2_bufs *bufs, uint8_t *begin, size_t len) {
   nghttp2_buf_chain *chain;
 
   chain = malloc(sizeof(nghttp2_buf_chain));
-  if(chain == NULL) {
+  if (chain == NULL) {
     return NGHTTP2_ERR_NOMEM;
   }
 
@@ -241,9 +217,8 @@ int nghttp2_bufs_wrap_init(nghttp2_bufs *bufs, uint8_t *begin, size_t len)
   return 0;
 }
 
-void nghttp2_bufs_wrap_free(nghttp2_bufs *bufs)
-{
-  if(bufs == NULL) {
+void nghttp2_bufs_wrap_free(nghttp2_bufs *bufs) {
+  if (bufs == NULL) {
     return;
   }
 
@@ -251,12 +226,11 @@ void nghttp2_bufs_wrap_free(nghttp2_bufs *bufs)
   bufs->head = NULL;
 }
 
-void nghttp2_bufs_seek_last_present(nghttp2_bufs *bufs)
-{
+void nghttp2_bufs_seek_last_present(nghttp2_bufs *bufs) {
   nghttp2_buf_chain *ci;
 
-  for(ci = bufs->cur; ci; ci = ci->next) {
-    if(nghttp2_buf_len(&ci->buf) == 0) {
+  for (ci = bufs->cur; ci; ci = ci->next) {
+    if (nghttp2_buf_len(&ci->buf) == 0) {
       return;
     } else {
       bufs->cur = ci;
@@ -264,42 +238,40 @@ void nghttp2_bufs_seek_last_present(nghttp2_bufs *bufs)
   }
 }
 
-ssize_t nghttp2_bufs_len(nghttp2_bufs *bufs)
-{
+ssize_t nghttp2_bufs_len(nghttp2_bufs *bufs) {
   nghttp2_buf_chain *ci;
   ssize_t len;
 
   len = 0;
-  for(ci = bufs->head; ci; ci = ci->next) {
+  for (ci = bufs->head; ci; ci = ci->next) {
     len += nghttp2_buf_len(&ci->buf);
   }
 
   return len;
 }
 
-static ssize_t bufs_avail(nghttp2_bufs *bufs)
-{
+static ssize_t bufs_avail(nghttp2_bufs *bufs) {
   return (ssize_t)(nghttp2_buf_avail(&bufs->cur->buf) +
-    (bufs->chunk_length - bufs->offset) * (bufs->max_chunk - bufs->chunk_used));
+                   (bufs->chunk_length - bufs->offset) *
+                       (bufs->max_chunk - bufs->chunk_used));
 }
 
-static int bufs_alloc_chain(nghttp2_bufs *bufs)
-{
+static int bufs_alloc_chain(nghttp2_bufs *bufs) {
   int rv;
   nghttp2_buf_chain *chain;
 
-  if(bufs->cur->next) {
+  if (bufs->cur->next) {
     bufs->cur = bufs->cur->next;
 
     return 0;
   }
 
-  if(bufs->max_chunk == bufs->chunk_used) {
+  if (bufs->max_chunk == bufs->chunk_used) {
     return NGHTTP2_ERR_BUFFER_ERROR;
   }
 
   rv = buf_chain_new(&chain, bufs->chunk_length);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
 
@@ -317,26 +289,25 @@ static int bufs_alloc_chain(nghttp2_bufs *bufs)
   return 0;
 }
 
-int nghttp2_bufs_add(nghttp2_bufs *bufs, const void *data, size_t len)
-{
+int nghttp2_bufs_add(nghttp2_bufs *bufs, const void *data, size_t len) {
   int rv;
   size_t nwrite;
   nghttp2_buf *buf;
   const uint8_t *p;
 
-  if(bufs_avail(bufs) < (ssize_t)len) {
+  if (bufs_avail(bufs) < (ssize_t)len) {
     return NGHTTP2_ERR_BUFFER_ERROR;
   }
 
   p = data;
 
-  while(len) {
+  while (len) {
     buf = &bufs->cur->buf;
 
     nwrite = nghttp2_min((size_t)nghttp2_buf_avail(buf), len);
-    if(nwrite == 0) {
+    if (nwrite == 0) {
       rv = bufs_alloc_chain(bufs);
-      if(rv != 0) {
+      if (rv != 0) {
         return rv;
       }
       continue;
@@ -350,31 +321,29 @@ int nghttp2_bufs_add(nghttp2_bufs *bufs, const void *data, size_t len)
   return 0;
 }
 
-static int bufs_ensure_addb(nghttp2_bufs *bufs)
-{
+static int bufs_ensure_addb(nghttp2_bufs *bufs) {
   int rv;
   nghttp2_buf *buf;
 
   buf = &bufs->cur->buf;
 
-  if(nghttp2_buf_avail(buf) > 0) {
+  if (nghttp2_buf_avail(buf) > 0) {
     return 0;
   }
 
   rv = bufs_alloc_chain(bufs);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
 
   return 0;
 }
 
-int nghttp2_bufs_addb(nghttp2_bufs *bufs, uint8_t b)
-{
+int nghttp2_bufs_addb(nghttp2_bufs *bufs, uint8_t b) {
   int rv;
 
   rv = bufs_ensure_addb(bufs);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
 
@@ -383,12 +352,11 @@ int nghttp2_bufs_addb(nghttp2_bufs *bufs, uint8_t b)
   return 0;
 }
 
-int nghttp2_bufs_addb_hold(nghttp2_bufs *bufs, uint8_t b)
-{
+int nghttp2_bufs_addb_hold(nghttp2_bufs *bufs, uint8_t b) {
   int rv;
 
   rv = bufs_ensure_addb(bufs);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
 
@@ -397,12 +365,11 @@ int nghttp2_bufs_addb_hold(nghttp2_bufs *bufs, uint8_t b)
   return 0;
 }
 
-int nghttp2_bufs_orb(nghttp2_bufs *bufs, uint8_t b)
-{
+int nghttp2_bufs_orb(nghttp2_bufs *bufs, uint8_t b) {
   int rv;
 
   rv = bufs_ensure_addb(bufs);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
 
@@ -411,12 +378,11 @@ int nghttp2_bufs_orb(nghttp2_bufs *bufs, uint8_t b)
   return 0;
 }
 
-int nghttp2_bufs_orb_hold(nghttp2_bufs *bufs, uint8_t b)
-{
+int nghttp2_bufs_orb_hold(nghttp2_bufs *bufs, uint8_t b) {
   int rv;
 
   rv = bufs_ensure_addb(bufs);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
 
@@ -425,8 +391,7 @@ int nghttp2_bufs_orb_hold(nghttp2_bufs *bufs, uint8_t b)
   return 0;
 }
 
-ssize_t nghttp2_bufs_remove(nghttp2_bufs *bufs, uint8_t **out)
-{
+ssize_t nghttp2_bufs_remove(nghttp2_bufs *bufs, uint8_t **out) {
   size_t len;
   nghttp2_buf_chain *chain;
   nghttp2_buf *buf;
@@ -435,28 +400,27 @@ ssize_t nghttp2_bufs_remove(nghttp2_bufs *bufs, uint8_t **out)
 
   len = 0;
 
-  for(chain = bufs->head; chain; chain = chain->next) {
+  for (chain = bufs->head; chain; chain = chain->next) {
     len += nghttp2_buf_len(&chain->buf);
   }
 
-  if(!len) {
+  if (!len) {
     res = NULL;
   } else {
     res = malloc(len);
 
-    if(res == NULL) {
+    if (res == NULL) {
       return NGHTTP2_ERR_NOMEM;
     }
   }
 
   nghttp2_buf_wrap_init(&resbuf, res, len);
 
-  for(chain = bufs->head; chain; chain = chain->next) {
+  for (chain = bufs->head; chain; chain = chain->next) {
     buf = &chain->buf;
 
-    if(resbuf.last) {
-      resbuf.last = nghttp2_cpymem(resbuf.last,
-                                   buf->pos, nghttp2_buf_len(buf));
+    if (resbuf.last) {
+      resbuf.last = nghttp2_cpymem(resbuf.last, buf->pos, nghttp2_buf_len(buf));
     }
 
     nghttp2_buf_reset(buf);
@@ -470,27 +434,26 @@ ssize_t nghttp2_bufs_remove(nghttp2_bufs *bufs, uint8_t **out)
   return (ssize_t)len;
 }
 
-void nghttp2_bufs_reset(nghttp2_bufs *bufs)
-{
+void nghttp2_bufs_reset(nghttp2_bufs *bufs) {
   nghttp2_buf_chain *chain, *ci;
   size_t k;
 
   k = bufs->chunk_keep;
 
-  for(ci = bufs->head; ci; ci = ci->next) {
+  for (ci = bufs->head; ci; ci = ci->next) {
     nghttp2_buf_reset(&ci->buf);
     nghttp2_buf_shift_right(&ci->buf, bufs->offset);
 
-    if(--k == 0) {
+    if (--k == 0) {
       break;
     }
   }
 
-  if(ci) {
+  if (ci) {
     chain = ci->next;
     ci->next = NULL;
 
-    for(ci = chain; ci;) {
+    for (ci = chain; ci;) {
       chain = ci->next;
 
       buf_chain_del(ci);
@@ -504,17 +467,12 @@ void nghttp2_bufs_reset(nghttp2_bufs *bufs)
   bufs->cur = bufs->head;
 }
 
-int nghttp2_bufs_advance(nghttp2_bufs *bufs)
-{
-  return bufs_alloc_chain(bufs);
-}
+int nghttp2_bufs_advance(nghttp2_bufs *bufs) { return bufs_alloc_chain(bufs); }
 
-int nghttp2_bufs_next_present(nghttp2_bufs *bufs)
-{
+int nghttp2_bufs_next_present(nghttp2_bufs *bufs) {
   nghttp2_buf_chain *chain;
 
   chain = bufs->cur->next;
 
   return chain && nghttp2_buf_len(&chain->buf);
 }
-
