@@ -41,19 +41,17 @@ extern const nghttp2_huff_decode huff_decode_table[][16];
  * unfilled bits in the pointed location is returned.
  */
 static ssize_t huff_encode_sym(nghttp2_bufs *bufs, size_t *avail_ptr,
-                               size_t rembits,
-                               const nghttp2_huff_sym *sym)
-{
+                               size_t rembits, const nghttp2_huff_sym *sym) {
   int rv;
   size_t nbits = sym->nbits;
 
-  for(;;) {
-    if(rembits > nbits) {
-      if(*avail_ptr) {
+  for (;;) {
+    if (rembits > nbits) {
+      if (*avail_ptr) {
         nghttp2_bufs_fast_orb_hold(bufs, sym->code << (rembits - nbits));
       } else {
         rv = nghttp2_bufs_orb_hold(bufs, sym->code << (rembits - nbits));
-        if(rv != 0) {
+        if (rv != 0) {
           return rv;
         }
 
@@ -65,12 +63,12 @@ static ssize_t huff_encode_sym(nghttp2_bufs *bufs, size_t *avail_ptr,
       break;
     }
 
-    if(*avail_ptr) {
+    if (*avail_ptr) {
       nghttp2_bufs_fast_orb(bufs, sym->code >> (nbits - rembits));
       --*avail_ptr;
     } else {
       rv = nghttp2_bufs_orb(bufs, sym->code >> (nbits - rembits));
-      if(rv != 0) {
+      if (rv != 0) {
         return rv;
       }
 
@@ -80,74 +78,72 @@ static ssize_t huff_encode_sym(nghttp2_bufs *bufs, size_t *avail_ptr,
     nbits -= rembits;
     rembits = 8;
 
-    if(nbits == 0) {
+    if (nbits == 0) {
       break;
     }
 
-    if(*avail_ptr) {
+    if (*avail_ptr) {
       nghttp2_bufs_fast_addb_hold(bufs, 0);
     } else {
       rv = nghttp2_bufs_addb_hold(bufs, 0);
-      if(rv != 0) {
+      if (rv != 0) {
         return rv;
       }
 
       *avail_ptr = nghttp2_bufs_cur_avail(bufs);
     }
   }
-  return rembits;
+  return (ssize_t)rembits;
 }
 
-size_t nghttp2_hd_huff_encode_count(const uint8_t *src, size_t len)
-{
+size_t nghttp2_hd_huff_encode_count(const uint8_t *src, size_t len) {
   size_t i;
   size_t nbits = 0;
 
-  for(i = 0; i < len; ++i) {
+  for (i = 0; i < len; ++i) {
     nbits += huff_sym_table[src[i]].nbits;
   }
   /* pad the prefix of EOS (256) */
   return (nbits + 7) / 8;
 }
 
-int nghttp2_hd_huff_encode(nghttp2_bufs *bufs,
-                           const uint8_t *src, size_t srclen)
-{
+int nghttp2_hd_huff_encode(nghttp2_bufs *bufs, const uint8_t *src,
+                           size_t srclen) {
   int rv;
-  int rembits = 8;
+  ssize_t rembits = 8;
   size_t i;
   size_t avail;
 
   avail = nghttp2_bufs_cur_avail(bufs);
 
-  for(i = 0; i < srclen; ++i) {
+  for (i = 0; i < srclen; ++i) {
     const nghttp2_huff_sym *sym = &huff_sym_table[src[i]];
-    if(rembits == 8) {
-      if(avail) {
+    if (rembits == 8) {
+      if (avail) {
         nghttp2_bufs_fast_addb_hold(bufs, 0);
       } else {
         rv = nghttp2_bufs_addb_hold(bufs, 0);
-        if(rv != 0) {
+        if (rv != 0) {
           return rv;
         }
         avail = nghttp2_bufs_cur_avail(bufs);
       }
     }
     rembits = huff_encode_sym(bufs, &avail, rembits, sym);
-    if(rembits < 0) {
-      return rembits;
+    if (rembits < 0) {
+      return (int)rembits;
     }
   }
   /* 256 is special terminal symbol, pad with its prefix */
-  if(rembits < 8) {
+  if (rembits < 8) {
     const nghttp2_huff_sym *sym = &huff_sym_table[256];
 
     /* Caution we no longer adjust avail here */
-    if(avail) {
+    if (avail) {
       nghttp2_bufs_fast_orb(bufs, sym->code >> (sym->nbits - rembits));
     } else {
       rv = nghttp2_bufs_orb(bufs, sym->code >> (sym->nbits - rembits));
-      if(rv != 0) {
+      if (rv != 0) {
         return rv;
       }
     }
@@ -156,16 +152,14 @@ int nghttp2_hd_huff_encode(nghttp2_bufs *bufs,
   return 0;
 }
 
-void nghttp2_hd_huff_decode_context_init(nghttp2_hd_huff_decode_context *ctx)
-{
+void nghttp2_hd_huff_decode_context_init(nghttp2_hd_huff_decode_context *ctx) {
   ctx->state = 0;
   ctx->accept = 1;
 }
 
 ssize_t nghttp2_hd_huff_decode(nghttp2_hd_huff_decode_context *ctx,
-                               nghttp2_bufs *bufs,
-                               const uint8_t *src, size_t srclen, int final)
-{
+                               nghttp2_bufs *bufs, const uint8_t *src,
+                               size_t srclen, int final) {
   size_t i, j;
   int rv;
   size_t avail;
@@ -174,22 +168,22 @@ ssize_t nghttp2_hd_huff_decode(nghttp2_hd_huff_decode_context *ctx,
 
   /* We use the decoding algorithm described in
      http://graphics.ics.uci.edu/pub/Prefix.pdf */
-  for(i = 0; i < srclen; ++i) {
+  for (i = 0; i < srclen; ++i) {
     uint8_t in = src[i] >> 4;
-    for(j = 0; j < 2; ++j) {
+    for (j = 0; j < 2; ++j) {
       const nghttp2_huff_decode *t;
 
       t = &huff_decode_table[ctx->state][in];
-      if(t->flags & NGHTTP2_HUFF_FAIL) {
+      if (t->flags & NGHTTP2_HUFF_FAIL) {
         return NGHTTP2_ERR_HEADER_COMP;
       }
-      if(t->flags & NGHTTP2_HUFF_SYM) {
-        if(avail) {
+      if (t->flags & NGHTTP2_HUFF_SYM) {
+        if (avail) {
           nghttp2_bufs_fast_addb(bufs, t->sym);
           --avail;
         } else {
           rv = nghttp2_bufs_addb(bufs, t->sym);
-          if(rv != 0) {
+          if (rv != 0) {
             return rv;
           }
           avail = nghttp2_bufs_cur_avail(bufs);
@@ -200,8 +194,8 @@ ssize_t nghttp2_hd_huff_decode(nghttp2_hd_huff_decode_context *ctx,
       in = src[i] & 0xf;
     }
   }
-  if(final && !ctx->accept) {
+  if (final && !ctx->accept) {
     return NGHTTP2_ERR_HEADER_COMP;
   }
-  return i;
+  return (ssize_t)i;
 }
