@@ -28,11 +28,10 @@
 
 #define INITIAL_TABLE_LENGTH 256
 
-int nghttp2_map_init(nghttp2_map *map)
-{
+int nghttp2_map_init(nghttp2_map *map) {
   map->tablelen = INITIAL_TABLE_LENGTH;
-  map->table = calloc(map->tablelen, sizeof(nghttp2_map_entry*));
-  if(map->table == NULL) {
+  map->table = calloc(map->tablelen, sizeof(nghttp2_map_entry *));
+  if (map->table == NULL) {
     return NGHTTP2_ERR_NOMEM;
   }
 
@@ -41,19 +40,15 @@ int nghttp2_map_init(nghttp2_map *map)
   return 0;
 }
 
-void nghttp2_map_free(nghttp2_map *map)
-{
-  free(map->table);
-}
+void nghttp2_map_free(nghttp2_map *map) { free(map->table); }
 
 void nghttp2_map_each_free(nghttp2_map *map,
                            int (*func)(nghttp2_map_entry *entry, void *ptr),
-                           void *ptr)
-{
+                           void *ptr) {
   size_t i;
-  for(i = 0; i < map->tablelen; ++i) {
+  for (i = 0; i < map->tablelen; ++i) {
     nghttp2_map_entry *entry;
-    for(entry = map->table[i]; entry;) {
+    for (entry = map->table[i]; entry;) {
       nghttp2_map_entry *next = entry->next;
       func(entry, ptr);
       entry = next;
@@ -64,15 +59,14 @@ void nghttp2_map_each_free(nghttp2_map *map,
 
 int nghttp2_map_each(nghttp2_map *map,
                      int (*func)(nghttp2_map_entry *entry, void *ptr),
-                     void *ptr)
-{
+                     void *ptr) {
   int rv;
   size_t i;
-  for(i = 0; i < map->tablelen; ++i) {
+  for (i = 0; i < map->tablelen; ++i) {
     nghttp2_map_entry *entry;
-    for(entry = map->table[i]; entry; entry = entry->next) {
+    for (entry = map->table[i]; entry; entry = entry->next) {
       rv = func(entry, ptr);
-      if(rv != 0) {
+      if (rv != 0) {
         return rv;
       }
     }
@@ -80,32 +74,29 @@ int nghttp2_map_each(nghttp2_map *map,
   return 0;
 }
 
-void nghttp2_map_entry_init(nghttp2_map_entry *entry, key_type key)
-{
+void nghttp2_map_entry_init(nghttp2_map_entry *entry, key_type key) {
   entry->key = key;
   entry->next = NULL;
 }
 
 /* Same hash function in android HashMap source code. */
 /* The |mod| must be power of 2 */
-static int32_t hash(int32_t h, size_t mod)
-{
+static int32_t hash(int32_t h, size_t mod) {
   h ^= (h >> 20) ^ (h >> 12);
   h ^= (h >> 7) ^ (h >> 4);
   return h & (mod - 1);
 }
 
 static int insert(nghttp2_map_entry **table, size_t tablelen,
-                  nghttp2_map_entry *entry)
-{
+                  nghttp2_map_entry *entry) {
   int32_t h = hash(entry->key, tablelen);
-  if(table[h] == NULL) {
+  if (table[h] == NULL) {
     table[h] = entry;
   } else {
     nghttp2_map_entry *p;
     /* We won't allow duplicated key, so check it out. */
-    for(p = table[h]; p; p = p->next) {
-      if(p->key == entry->key) {
+    for (p = table[h]; p; p = p->next) {
+      if (p->key == entry->key) {
         return NGHTTP2_ERR_INVALID_ARGUMENT;
       }
     }
@@ -116,18 +107,17 @@ static int insert(nghttp2_map_entry **table, size_t tablelen,
 }
 
 /* new_tablelen must be power of 2 */
-static int resize(nghttp2_map *map, size_t new_tablelen)
-{
+static int resize(nghttp2_map *map, size_t new_tablelen) {
   size_t i;
   nghttp2_map_entry **new_table;
-  new_table = calloc(new_tablelen, sizeof(nghttp2_map_entry*));
-  if(new_table == NULL) {
+  new_table = calloc(new_tablelen, sizeof(nghttp2_map_entry *));
+  if (new_table == NULL) {
     return NGHTTP2_ERR_NOMEM;
   }
 
-  for(i = 0; i < map->tablelen; ++i) {
+  for (i = 0; i < map->tablelen; ++i) {
     nghttp2_map_entry *entry;
-    for(entry = map->table[i]; entry;) {
+    for (entry = map->table[i]; entry;) {
       nghttp2_map_entry *next = entry->next;
       entry->next = NULL;
       /* This function must succeed */
@@ -142,46 +132,43 @@ static int resize(nghttp2_map *map, size_t new_tablelen)
   return 0;
 }
 
-int nghttp2_map_insert(nghttp2_map *map, nghttp2_map_entry *new_entry)
-{
+int nghttp2_map_insert(nghttp2_map *map, nghttp2_map_entry *new_entry) {
   int rv;
   /* Load factor is 0.75 */
-  if((map->size + 1) * 4 > map->tablelen * 3) {
+  if ((map->size + 1) * 4 > map->tablelen * 3) {
     rv = resize(map, map->tablelen * 2);
-    if(rv != 0) {
+    if (rv != 0) {
       return rv;
     }
   }
   rv = insert(map->table, map->tablelen, new_entry);
-  if(rv != 0) {
+  if (rv != 0) {
     return rv;
   }
   ++map->size;
   return 0;
 }
 
-nghttp2_map_entry* nghttp2_map_find(nghttp2_map *map, key_type key)
-{
+nghttp2_map_entry *nghttp2_map_find(nghttp2_map *map, key_type key) {
   int32_t h;
   nghttp2_map_entry *entry;
   h = hash(key, map->tablelen);
-  for(entry = map->table[h]; entry; entry = entry->next) {
-    if(entry->key == key) {
+  for (entry = map->table[h]; entry; entry = entry->next) {
+    if (entry->key == key) {
       return entry;
     }
   }
   return NULL;
 }
 
-int nghttp2_map_remove(nghttp2_map *map, key_type key)
-{
+int nghttp2_map_remove(nghttp2_map *map, key_type key) {
   int32_t h;
   nghttp2_map_entry *entry, *prev;
   h = hash(key, map->tablelen);
   prev = NULL;
-  for(entry = map->table[h]; entry; entry = entry->next) {
-    if(entry->key == key) {
-      if(prev == NULL) {
+  for (entry = map->table[h]; entry; entry = entry->next) {
+    if (entry->key == key) {
+      if (prev == NULL) {
         map->table[h] = entry->next;
       } else {
         prev->next = entry->next;
@@ -194,7 +181,4 @@ int nghttp2_map_remove(nghttp2_map *map, key_type key)
   return NGHTTP2_ERR_INVALID_ARGUMENT;
 }
 
-size_t nghttp2_map_size(nghttp2_map *map)
-{
-  return map->size;
-}
+size_t nghttp2_map_size(nghttp2_map *map) { return map->size; }
