@@ -23,7 +23,7 @@
  * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif // HAVE_CONFIG_H
 
 #include <unistd.h>
@@ -45,7 +45,6 @@ extern "C" {
 #include "nghttp2_frame.h"
 
 #include "comp_helper.h"
-
 }
 
 typedef struct {
@@ -60,28 +59,24 @@ static deflate_config config;
 static size_t input_sum;
 static size_t output_sum;
 
-static char to_hex_digit(uint8_t n)
-{
-  if(n > 9) {
+static char to_hex_digit(uint8_t n) {
+  if (n > 9) {
     return n - 10 + 'a';
   }
   return n + '0';
 }
 
-static void to_hex(char *dest, const uint8_t *src, size_t len)
-{
+static void to_hex(char *dest, const uint8_t *src, size_t len) {
   size_t i;
-  for(i = 0; i < len; ++i) {
+  for (i = 0; i < len; ++i) {
     *dest++ = to_hex_digit(src[i] >> 4);
     *dest++ = to_hex_digit(src[i] & 0xf);
   }
 }
 
-static void output_to_json(nghttp2_hd_deflater *deflater,
-                           nghttp2_bufs *bufs, size_t inputlen,
-                           const std::vector<nghttp2_nv> nva,
-                           int seq)
-{
+static void output_to_json(nghttp2_hd_deflater *deflater, nghttp2_bufs *bufs,
+                           size_t inputlen, const std::vector<nghttp2_nv> &nva,
+                           int seq) {
   auto len = nghttp2_bufs_len(bufs);
   auto hex = std::vector<char>(len * 2);
   auto obj = json_object();
@@ -94,26 +89,25 @@ static void output_to_json(nghttp2_hd_deflater *deflater,
                       json_real(comp_ratio));
 
   auto hexp = hex.data();
-  for(auto ci = bufs->head; ci; ci = ci->next) {
+  for (auto ci = bufs->head; ci; ci = ci->next) {
     auto buf = &ci->buf;
     to_hex(hexp, buf->pos, nghttp2_buf_len(buf));
     hexp += nghttp2_buf_len(buf);
   }
 
-  if(len == 0) {
+  if (len == 0) {
     json_object_set_new(obj, "wire", json_string(""));
   } else {
     json_object_set_new(obj, "wire", json_pack("s#", hex.data(), hex.size()));
   }
   json_object_set_new(obj, "headers", dump_headers(nva.data(), nva.size()));
-  if(seq == 0) {
+  if (seq == 0) {
     // We only change the header table size only once at the beginning
     json_object_set_new(obj, "header_table_size",
                         json_integer(config.table_size));
   }
-  if(config.dump_header_table) {
-    json_object_set_new(obj, "header_table",
-                        dump_header_table(&deflater->ctx));
+  if (config.dump_header_table) {
+    json_object_set_new(obj, "header_table", dump_header_table(&deflater->ctx));
   }
   json_dumpf(obj, stdout, JSON_PRESERVE_ORDER | JSON_INDENT(2));
   printf("\n");
@@ -121,17 +115,16 @@ static void output_to_json(nghttp2_hd_deflater *deflater,
 }
 
 static void deflate_hd(nghttp2_hd_deflater *deflater,
-                       const std::vector<nghttp2_nv>& nva,
-                       size_t inputlen, int seq)
-{
+                       const std::vector<nghttp2_nv> &nva, size_t inputlen,
+                       int seq) {
   ssize_t rv;
   nghttp2_bufs bufs;
 
   nghttp2_bufs_init2(&bufs, 4096, 16, 0);
 
-  rv = nghttp2_hd_deflate_hd_bufs(deflater, &bufs,
-                                  (nghttp2_nv*)nva.data(), nva.size());
-  if(rv < 0) {
+  rv = nghttp2_hd_deflate_hd_bufs(deflater, &bufs, (nghttp2_nv *)nva.data(),
+                                  nva.size());
+  if (rv < 0) {
     fprintf(stderr, "deflate failed with error code %zd at %d\n", rv, seq);
     exit(EXIT_FAILURE);
   }
@@ -143,44 +136,43 @@ static void deflate_hd(nghttp2_hd_deflater *deflater,
   nghttp2_bufs_free(&bufs);
 }
 
-static int deflate_hd_json(json_t *obj, nghttp2_hd_deflater *deflater, int seq)
-{
+static int deflate_hd_json(json_t *obj, nghttp2_hd_deflater *deflater,
+                           int seq) {
   size_t inputlen = 0;
 
   auto js = json_object_get(obj, "headers");
-  if(js == nullptr) {
+  if (js == nullptr) {
     fprintf(stderr, "'headers' key is missing at %d\n", seq);
     return -1;
   }
-  if(!json_is_array(js)) {
-    fprintf(stderr,
-            "The value of 'headers' key must be an array at %d\n", seq);
+  if (!json_is_array(js)) {
+    fprintf(stderr, "The value of 'headers' key must be an array at %d\n", seq);
     return -1;
   }
 
   auto len = json_array_size(js);
   auto nva = std::vector<nghttp2_nv>(len);
 
-  for(size_t i = 0; i < len; ++i) {
+  for (size_t i = 0; i < len; ++i) {
     auto nv_pair = json_array_get(js, i);
     const char *name;
     json_t *value;
 
-    if(!json_is_object(nv_pair) || json_object_size(nv_pair) != 1) {
+    if (!json_is_object(nv_pair) || json_object_size(nv_pair) != 1) {
       fprintf(stderr, "bad formatted name/value pair object at %d\n", seq);
       return -1;
     }
 
     json_object_foreach(nv_pair, name, value) {
-      nva[i].name = (uint8_t*)name;
+      nva[i].name = (uint8_t *)name;
       nva[i].namelen = strlen(name);
 
-      if(!json_is_string(value)) {
+      if (!json_is_string(value)) {
         fprintf(stderr, "value is not string at %d\n", seq);
         return -1;
       }
 
-      nva[i].value = (uint8_t*)json_string_value(value);
+      nva[i].value = (uint8_t *)json_string_value(value);
       nva[i].valuelen = strlen(json_string_value(value));
 
       nva[i].flags = NGHTTP2_NV_FLAG_NONE;
@@ -194,37 +186,34 @@ static int deflate_hd_json(json_t *obj, nghttp2_hd_deflater *deflater, int seq)
   return 0;
 }
 
-static void init_deflater(nghttp2_hd_deflater *deflater)
-{
+static void init_deflater(nghttp2_hd_deflater *deflater) {
   nghttp2_hd_deflate_init2(deflater, config.deflate_table_size);
   nghttp2_hd_deflate_change_table_size(deflater, config.table_size);
 }
 
-static void deinit_deflater(nghttp2_hd_deflater *deflater)
-{
+static void deinit_deflater(nghttp2_hd_deflater *deflater) {
   nghttp2_hd_deflate_free(deflater);
 }
 
-static int perform(void)
-{
+static int perform(void) {
   json_error_t error;
   nghttp2_hd_deflater deflater;
 
   auto json = json_loadf(stdin, 0, &error);
 
-  if(json == nullptr) {
+  if (json == nullptr) {
     fprintf(stderr, "JSON loading failed\n");
     exit(EXIT_FAILURE);
   }
 
   auto cases = json_object_get(json, "cases");
 
-  if(cases == nullptr) {
+  if (cases == nullptr) {
     fprintf(stderr, "Missing 'cases' key in root object\n");
     exit(EXIT_FAILURE);
   }
 
-  if(!json_is_array(cases)) {
+  if (!json_is_array(cases)) {
     fprintf(stderr, "'cases' must be JSON array\n");
     exit(EXIT_FAILURE);
   }
@@ -233,17 +222,16 @@ static int perform(void)
   output_json_header();
   auto len = json_array_size(cases);
 
-  for(size_t i = 0; i < len; ++i) {
+  for (size_t i = 0; i < len; ++i) {
     auto obj = json_array_get(cases, i);
-    if(!json_is_object(obj)) {
-      fprintf(stderr, "Unexpected JSON type at %zu. It should be object.\n",
-              i);
+    if (!json_is_object(obj)) {
+      fprintf(stderr, "Unexpected JSON type at %zu. It should be object.\n", i);
       continue;
     }
-    if(deflate_hd_json(obj, &deflater, i) != 0) {
+    if (deflate_hd_json(obj, &deflater, i) != 0) {
       continue;
     }
-    if(i + 1 < len) {
+    if (i + 1 < len) {
       printf(",\n");
     }
   }
@@ -253,65 +241,67 @@ static int perform(void)
   return 0;
 }
 
-static int perform_from_http1text(void)
-{
+static int perform_from_http1text(void) {
   char line[1 << 14];
   int seq = 0;
   nghttp2_hd_deflater deflater;
   init_deflater(&deflater);
   output_json_header();
-  for(;;) {
+  for (;;) {
     std::vector<nghttp2_nv> nva;
     int end = 0;
     size_t inputlen = 0;
 
-    for(;;) {
+    for (;;) {
       char *rv = fgets(line, sizeof(line), stdin);
       char *val, *val_end;
-      if(rv == nullptr) {
+      if (rv == nullptr) {
         end = 1;
         break;
-      } else if(line[0] == '\n') {
+      } else if (line[0] == '\n') {
         break;
       }
 
       nva.emplace_back();
-      auto& nv = nva.back();
+      auto &nv = nva.back();
 
-      val = strchr(line+1, ':');
-      if(val == nullptr) {
+      val = strchr(line + 1, ':');
+      if (val == nullptr) {
         fprintf(stderr, "Bad HTTP/1 header field format at %d.\n", seq);
         exit(EXIT_FAILURE);
       }
       *val = '\0';
       ++val;
-      for(; *val && (*val == ' ' || *val == '\t'); ++val);
-      for(val_end = val; *val_end && (*val_end != '\r' && *val_end != '\n');
-          ++val_end);
+      for (; *val && (*val == ' ' || *val == '\t'); ++val)
+        ;
+      for (val_end = val; *val_end && (*val_end != '\r' && *val_end != '\n');
+           ++val_end)
+        ;
       *val_end = '\0';
 
       nv.namelen = strlen(line);
       nv.valuelen = strlen(val);
-      nv.name = (uint8_t*)strdup(line);
-      nv.value = (uint8_t*)strdup(val);
+      nv.name = (uint8_t *)strdup(line);
+      nv.value = (uint8_t *)strdup(val);
       nv.flags = NGHTTP2_NV_FLAG_NONE;
 
       inputlen += nv.namelen + nv.valuelen;
     }
 
-    if(!end) {
-      if(seq > 0) {
+    if (!end) {
+      if (seq > 0) {
         printf(",\n");
       }
       deflate_hd(&deflater, nva, inputlen, seq);
     }
 
-    for(auto& nv : nva) {
+    for (auto &nv : nva) {
       free(nv.name);
       free(nv.value);
     }
 
-    if(end) break;
+    if (end)
+      break;
     ++seq;
   }
   output_json_footer();
@@ -319,8 +309,7 @@ static int perform_from_http1text(void)
   return 0;
 }
 
-static void print_help(void)
-{
+static void print_help(void) {
   std::cout << R"(HPACK HTTP/2 header encoder
 Usage: deflatehd [OPTIONS] < INPUT
 
@@ -385,33 +374,30 @@ OPTIONS:
                       buffer.
                       Default: 4096
     -d, --dump-header-table
-                      Output dynamic header table.)"
-            << std::endl;
+                      Output dynamic header table.)" << std::endl;
 }
 
 static struct option long_options[] = {
-  {"http1text", no_argument, nullptr, 't'},
-  {"table-size", required_argument, nullptr, 's'},
-  {"deflate-table-size", required_argument, nullptr, 'S'},
-  {"dump-header-table", no_argument, nullptr, 'd'},
-  {nullptr, 0, nullptr, 0 }
-};
+    {"http1text", no_argument, nullptr, 't'},
+    {"table-size", required_argument, nullptr, 's'},
+    {"deflate-table-size", required_argument, nullptr, 'S'},
+    {"dump-header-table", no_argument, nullptr, 'd'},
+    {nullptr, 0, nullptr, 0}};
 
-int main(int argc, char **argv)
-{
+int main(int argc, char **argv) {
   char *end;
 
   config.table_size = NGHTTP2_HD_DEFAULT_MAX_BUFFER_SIZE;
   config.deflate_table_size = NGHTTP2_HD_DEFAULT_MAX_DEFLATE_BUFFER_SIZE;
   config.http1text = 0;
   config.dump_header_table = 0;
-  while(1) {
+  while (1) {
     int option_index = 0;
     int c = getopt_long(argc, argv, "S:dhs:t", long_options, &option_index);
-    if(c == -1) {
+    if (c == -1) {
       break;
     }
-    switch(c) {
+    switch (c) {
     case 'h':
       print_help();
       exit(EXIT_SUCCESS);
@@ -423,7 +409,7 @@ int main(int argc, char **argv)
       // --table-size
       errno = 0;
       config.table_size = strtoul(optarg, &end, 10);
-      if(errno == ERANGE || *end != '\0') {
+      if (errno == ERANGE || *end != '\0') {
         fprintf(stderr, "-s: Bad option value\n");
         exit(EXIT_FAILURE);
       }
@@ -432,7 +418,7 @@ int main(int argc, char **argv)
       // --deflate-table-size
       errno = 0;
       config.deflate_table_size = strtoul(optarg, &end, 10);
-      if(errno == ERANGE || *end != '\0') {
+      if (errno == ERANGE || *end != '\0') {
         fprintf(stderr, "-S: Bad option value\n");
         exit(EXIT_FAILURE);
       }
@@ -447,7 +433,7 @@ int main(int argc, char **argv)
       break;
     }
   }
-  if(config.http1text) {
+  if (config.http1text) {
     perform_from_http1text();
   } else {
     perform();
@@ -455,7 +441,7 @@ int main(int argc, char **argv)
 
   auto comp_ratio = input_sum == 0 ? 0.0 : (double)output_sum / input_sum;
 
-  fprintf(stderr, "Overall: input=%zu output=%zu ratio=%.02f\n",
-          input_sum, output_sum, comp_ratio);
+  fprintf(stderr, "Overall: input=%zu output=%zu ratio=%.02f\n", input_sum,
+          output_sum, comp_ratio);
   return 0;
 }
