@@ -43,15 +43,19 @@
 
 #include <openssl/ssl.h>
 
+#include "http2.h"
+
 namespace h2load {
 
 class Session;
 
 struct Config {
   std::vector<std::vector<nghttp2_nv>> nva;
-  std::vector<std::vector<const char*>> nv;
+  std::vector<std::vector<const char *>> nv;
+  nghttp2::Headers custom_headers;
   std::string scheme;
   std::string host;
+  std::string ifile;
   addrinfo *addrs;
   size_t nreqs;
   size_t nclients;
@@ -60,13 +64,9 @@ struct Config {
   ssize_t max_concurrent_streams;
   size_t window_bits;
   size_t connection_window_bits;
-  enum {
-    PROTO_HTTP2,
-    PROTO_SPDY2,
-    PROTO_SPDY3,
-    PROTO_SPDY3_1
-  } no_tls_proto;
+  enum { PROTO_HTTP2, PROTO_SPDY2, PROTO_SPDY3, PROTO_SPDY3_1 } no_tls_proto;
   uint16_t port;
+  uint16_t default_port;
   bool verbose;
 
   Config();
@@ -100,10 +100,7 @@ struct Stats {
   size_t status[6];
 };
 
-enum ClientState {
-  CLIENT_IDLE,
-  CLIENT_CONNECTED
-};
+enum ClientState { CLIENT_IDLE, CLIENT_CONNECTED };
 
 struct Client;
 
@@ -113,16 +110,14 @@ struct Worker {
   event_base *evbase;
   SSL_CTX *ssl_ctx;
   Config *config;
-  event *term_timer;
   size_t progress_interval;
   uint32_t id;
+  bool tls_info_report_done;
 
   Worker(uint32_t id, SSL_CTX *ssl_ctx, size_t nreq_todo, size_t nclients,
          Config *config);
   ~Worker();
   void run();
-  void schedule_terminate();
-  void terminate_session();
 };
 
 struct Stream {
@@ -143,8 +138,7 @@ struct Client {
   size_t req_todo;
   // The number of requests this client has issued so far.
   size_t req_started;
-  // The number of requests this client has issued and got response so
-  // far.
+  // The number of requests this client has done so far.
   size_t req_done;
 
   Client(Worker *worker, size_t req_todo);
@@ -155,13 +149,13 @@ struct Client {
   void submit_request();
   void process_abandoned_streams();
   void report_progress();
+  void report_tls_info();
   void terminate_session();
   int on_connect();
   int on_read();
   int on_write();
   void on_request(int32_t stream_id);
-  void on_header(int32_t stream_id,
-                 const uint8_t *name, size_t namelen,
+  void on_header(int32_t stream_id, const uint8_t *name, size_t namelen,
                  const uint8_t *value, size_t valuelen);
   void on_stream_close(int32_t stream_id, bool success);
 };
