@@ -44,6 +44,8 @@
 
 namespace shrpx {
 
+struct LogFragment;
+
 namespace ssl {
 
 struct CertLookupTree;
@@ -65,6 +67,7 @@ extern const char SHRPX_OPT_HTTP2_PROXY[];
 extern const char SHRPX_OPT_HTTP2_BRIDGE[];
 extern const char SHRPX_OPT_CLIENT_PROXY[];
 extern const char SHRPX_OPT_ADD_X_FORWARDED_FOR[];
+extern const char SHRPX_OPT_STRIP_INCOMING_X_FORWARDED_FOR[];
 extern const char SHRPX_OPT_NO_VIA[];
 extern const char SHRPX_OPT_FRONTEND_HTTP2_READ_TIMEOUT[];
 extern const char SHRPX_OPT_FRONTEND_READ_TIMEOUT[];
@@ -75,6 +78,7 @@ extern const char SHRPX_OPT_STREAM_READ_TIMEOUT[];
 extern const char SHRPX_OPT_STREAM_WRITE_TIMEOUT[];
 extern const char SHRPX_OPT_ACCESSLOG_FILE[];
 extern const char SHRPX_OPT_ACCESSLOG_SYSLOG[];
+extern const char SHRPX_OPT_ACCESSLOG_FORMAT[];
 extern const char SHRPX_OPT_ERRORLOG_FILE[];
 extern const char SHRPX_OPT_ERRORLOG_SYSLOG[];
 extern const char SHRPX_OPT_BACKEND_KEEP_ALIVE_TIMEOUT[];
@@ -129,21 +133,12 @@ union sockaddr_union {
   sockaddr_in in;
 };
 
-enum shrpx_proto {
-  PROTO_HTTP2,
-  PROTO_HTTP
-};
+enum shrpx_proto { PROTO_HTTP2, PROTO_HTTP };
 
 struct AltSvc {
   AltSvc()
-    : protocol_id(nullptr),
-      host(nullptr),
-      origin(nullptr),
-      protocol_id_len(0),
-      host_len(0),
-      origin_len(0),
-      port(0)
-  {}
+      : protocol_id(nullptr), host(nullptr), origin(nullptr),
+        protocol_id_len(0), host_len(0), origin_len(0), port(0) {}
 
   char *protocol_id;
   char *host;
@@ -162,6 +157,7 @@ struct Config {
   std::vector<AltSvc> altsvcs;
   std::vector<std::pair<std::string, std::string>> add_response_headers;
   std::vector<unsigned char> alpn_prefs;
+  std::vector<LogFragment> accesslog_format;
   std::shared_ptr<std::string> cached_time;
   sockaddr_union downstream_addr;
   // binary form of http proxy host and port
@@ -203,10 +199,10 @@ struct Config {
   // list of supported NPN/ALPN protocol strings in the order of
   // preference. The each element of this list is a NULL-terminated
   // string.
-  std::vector<char*> npn_list;
+  std::vector<char *> npn_list;
   // list of supported SSL/TLS protocol strings. The each element of
   // this list is a NULL-terminated string.
-  std::vector<char*> tls_proto_list;
+  std::vector<char *> tls_proto_list;
   // Path to file containing CA certificate solely used for client
   // certificate validation
   std::unique_ptr<char[]> verify_client_cacert;
@@ -249,6 +245,7 @@ struct Config {
   int argc;
   uid_t uid;
   gid_t gid;
+  pid_t pid;
   uint16_t port;
   uint16_t downstream_port;
   // port in http proxy URI
@@ -260,6 +257,7 @@ struct Config {
   bool http2_bridge;
   bool client_proxy;
   bool add_x_forwarded_for;
+  bool strip_incoming_x_forwarded_for;
   bool no_via;
   bool upstream_no_tls;
   bool downstream_no_tls;
@@ -278,8 +276,8 @@ struct Config {
   bool no_location_rewrite;
 };
 
-const Config* get_config();
-Config* mod_config();
+const Config *get_config();
+Config *mod_config();
 void create_config();
 
 // Parses option name |opt| and value |optarg|.  The results are
@@ -303,12 +301,12 @@ std::string read_passwd_from_file(const char *filename);
 // |s| and the caller must leave it as is after this call.  This
 // function copies |s| and first element in the return value points to
 // it.  It is caller's responsibility to deallocate its memory.
-std::vector<char*> parse_config_str_list(const char *s);
+std::vector<char *> parse_config_str_list(const char *s);
 
 // Clears all elements of |list|, which is returned by
 // parse_config_str_list().  If list is not empty, list[0] is freed by
 // free(2).  After this call, list.empty() must be true.
-void clear_config_str_list(std::vector<char*>& list);
+void clear_config_str_list(std::vector<char *> &list);
 
 // Parses header field in |optarg|.  We expect header field is formed
 // like "NAME: VALUE".  We require that NAME is non empty string.  ":"
@@ -316,19 +314,25 @@ void clear_config_str_list(std::vector<char*>& list);
 // allowed.  This function returns pair of NAME and VALUE.
 std::pair<std::string, std::string> parse_header(const char *optarg);
 
+std::vector<LogFragment> parse_log_format(const char *optarg);
+
 // Returns a copy of NULL-terminated string |val|.
 std::unique_ptr<char[]> strcopy(const char *val);
 
+// Returns a copy of string |val| of length |n|.  The returned string
+// will be NULL-terminated.
+std::unique_ptr<char[]> strcopy(const char *val, size_t n);
+
 // Returns a copy of val.c_str().
-std::unique_ptr<char[]> strcopy(const std::string& val);
+std::unique_ptr<char[]> strcopy(const std::string &val);
 
 // Returns string for syslog |facility|.
-const char* str_syslog_facility(int facility);
+const char *str_syslog_facility(int facility);
 
 // Returns integer value of syslog |facility| string.
 int int_syslog_facility(const char *strfacility);
 
-FILE* open_file_for_write(const char *filename);
+FILE *open_file_for_write(const char *filename);
 
 } // namespace shrpx
 
