@@ -33,6 +33,7 @@
 
 #include "shrpx_upstream.h"
 #include "shrpx_downstream_queue.h"
+#include "libevent_util.h"
 
 namespace shrpx {
 
@@ -50,15 +51,15 @@ public:
   virtual int on_downstream_abort_request(Downstream *downstream,
                                           unsigned int status_code);
   int send();
-  virtual ClientHandler* get_client_handler() const;
+  virtual ClientHandler *get_client_handler() const;
   virtual bufferevent_data_cb get_downstream_readcb();
   virtual bufferevent_data_cb get_downstream_writecb();
   virtual bufferevent_event_cb get_downstream_eventcb();
   void add_pending_downstream(std::unique_ptr<Downstream> downstream);
   void remove_downstream(Downstream *downstream);
-  Downstream* find_downstream(int32_t stream_id);
+  Downstream *find_downstream(int32_t stream_id);
 
-  nghttp2_session* get_http2_session();
+  nghttp2_session *get_http2_session();
 
   int rst_stream(Downstream *downstream, uint32_t error_code);
   int terminate_session(uint32_t error_code);
@@ -69,10 +70,12 @@ public:
                           size_t consumed);
 
   virtual int on_downstream_header_complete(Downstream *downstream);
-  virtual int on_downstream_body(Downstream *downstream,
-                                 const uint8_t *data, size_t len, bool flush);
+  virtual int on_downstream_body(Downstream *downstream, const uint8_t *data,
+                                 size_t len, bool flush);
   virtual int on_downstream_body_complete(Downstream *downstream);
 
+  virtual void on_handler_delete();
+
   virtual void reset_timeouts();
 
   bool get_flow_control() const;
@@ -84,9 +87,12 @@ public:
   void stop_settings_timer();
   int consume(int32_t stream_id, size_t len);
   void log_response_headers(Downstream *downstream,
-                            const std::vector<nghttp2_nv>& nva) const;
+                            const std::vector<nghttp2_nv> &nva) const;
   void maintain_downstream_concurrency();
   void initiate_downstream(std::unique_ptr<Downstream> downstream);
+
+  nghttp2::util::EvbufferBuffer sendbuf;
+
 private:
   DownstreamQueue downstream_queue_;
   std::unique_ptr<HttpsUpstream> pre_upstream_;
