@@ -44,31 +44,26 @@ using namespace nghttp2;
 namespace shrpx {
 
 namespace {
-const size_t OUTBUF_MAX_THRES = 16*1024;
+const size_t OUTBUF_MAX_THRES = 16 * 1024;
 } // namespace
 
 HttpsUpstream::HttpsUpstream(ClientHandler *handler)
-  : handler_(handler),
-    current_header_length_(0),
-    ioctrl_(handler->get_bev())
-{
+    : handler_(handler), current_header_length_(0),
+      ioctrl_(handler->get_bev()) {
   http_parser_init(&htp_, HTTP_REQUEST);
   htp_.data = this;
 }
 
-HttpsUpstream::~HttpsUpstream()
-{}
+HttpsUpstream::~HttpsUpstream() {}
 
-void HttpsUpstream::reset_current_header_length()
-{
+void HttpsUpstream::reset_current_header_length() {
   current_header_length_ = 0;
 }
 
 namespace {
-int htp_msg_begin(http_parser *htp)
-{
-  auto upstream = static_cast<HttpsUpstream*>(htp->data);
-  if(LOG_ENABLED(INFO)) {
+int htp_msg_begin(http_parser *htp) {
+  auto upstream = static_cast<HttpsUpstream *>(htp->data);
+  if (LOG_ENABLED(INFO)) {
     ULOG(INFO, upstream) << "HTTP request started";
   }
   upstream->reset_current_header_length();
@@ -79,9 +74,8 @@ int htp_msg_begin(http_parser *htp)
 } // namespace
 
 namespace {
-int htp_uricb(http_parser *htp, const char *data, size_t len)
-{
-  auto upstream = static_cast<HttpsUpstream*>(htp->data);
+int htp_uricb(http_parser *htp, const char *data, size_t len) {
+  auto upstream = static_cast<HttpsUpstream *>(htp->data);
   auto downstream = upstream->get_downstream();
   downstream->append_request_path(data, len);
   return 0;
@@ -89,17 +83,16 @@ int htp_uricb(http_parser *htp, const char *data, size_t len)
 } // namespace
 
 namespace {
-int htp_hdr_keycb(http_parser *htp, const char *data, size_t len)
-{
-  auto upstream = static_cast<HttpsUpstream*>(htp->data);
+int htp_hdr_keycb(http_parser *htp, const char *data, size_t len) {
+  auto upstream = static_cast<HttpsUpstream *>(htp->data);
   auto downstream = upstream->get_downstream();
-  if(downstream->get_request_header_key_prev()) {
+  if (downstream->get_request_header_key_prev()) {
     downstream->append_last_request_header_key(data, len);
   } else {
     downstream->add_request_header(std::string(data, len), "");
   }
-  if(downstream->get_request_headers_sum() > Downstream::MAX_HEADERS_SUM) {
-    if(LOG_ENABLED(INFO)) {
+  if (downstream->get_request_headers_sum() > Downstream::MAX_HEADERS_SUM) {
+    if (LOG_ENABLED(INFO)) {
       ULOG(INFO, upstream) << "Too large header block size="
                            << downstream->get_request_headers_sum();
     }
@@ -110,17 +103,16 @@ int htp_hdr_keycb(http_parser *htp, const char *data, size_t len)
 } // namespace
 
 namespace {
-int htp_hdr_valcb(http_parser *htp, const char *data, size_t len)
-{
-  auto upstream = static_cast<HttpsUpstream*>(htp->data);
+int htp_hdr_valcb(http_parser *htp, const char *data, size_t len) {
+  auto upstream = static_cast<HttpsUpstream *>(htp->data);
   auto downstream = upstream->get_downstream();
-  if(downstream->get_request_header_key_prev()) {
+  if (downstream->get_request_header_key_prev()) {
     downstream->set_last_request_header_value(std::string(data, len));
   } else {
     downstream->append_last_request_header_value(data, len);
   }
-  if(downstream->get_request_headers_sum() > Downstream::MAX_HEADERS_SUM) {
-    if(LOG_ENABLED(INFO)) {
+  if (downstream->get_request_headers_sum() > Downstream::MAX_HEADERS_SUM) {
+    if (LOG_ENABLED(INFO)) {
       ULOG(INFO, upstream) << "Too large header block size="
                            << downstream->get_request_headers_sum();
     }
@@ -131,29 +123,30 @@ int htp_hdr_valcb(http_parser *htp, const char *data, size_t len)
 } // namespace
 
 namespace {
-int htp_hdrs_completecb(http_parser *htp)
-{
+int htp_hdrs_completecb(http_parser *htp) {
   int rv;
-  auto upstream = static_cast<HttpsUpstream*>(htp->data);
-  if(LOG_ENABLED(INFO)) {
+  auto upstream = static_cast<HttpsUpstream *>(htp->data);
+  if (LOG_ENABLED(INFO)) {
     ULOG(INFO, upstream) << "HTTP request headers completed";
   }
   auto downstream = upstream->get_downstream();
 
-  downstream->set_request_method(http_method_str((enum http_method)htp->method));
+  downstream->set_request_method(
+      http_method_str((enum http_method)htp->method));
   downstream->set_request_major(htp->http_major);
   downstream->set_request_minor(htp->http_minor);
+  downstream->set_request_start_time(std::chrono::high_resolution_clock::now());
 
   downstream->set_request_connection_close(!http_should_keep_alive(htp));
 
-  if(LOG_ENABLED(INFO)) {
+  if (LOG_ENABLED(INFO)) {
     std::stringstream ss;
     ss << downstream->get_request_method() << " "
        << downstream->get_request_path() << " "
        << "HTTP/" << downstream->get_request_major() << "."
        << downstream->get_request_minor() << "\n";
-    const auto& headers = downstream->get_request_headers();
-    for(size_t i = 0; i < headers.size(); ++i) {
+    const auto &headers = downstream->get_request_headers();
+    for (size_t i = 0; i < headers.size(); ++i) {
       ss << TTY_HTTP_HD << headers[i].name << TTY_RST << ": "
          << headers[i].value << "\n";
     }
@@ -161,33 +154,27 @@ int htp_hdrs_completecb(http_parser *htp)
   }
 
   downstream->normalize_request_headers();
-  auto& nva = downstream->get_request_headers();
-
-  auto user_agent = http2::get_header(nva, "user-agent");
-
-  downstream->set_request_user_agent(http2::value_to_str(user_agent));
 
   downstream->inspect_http1_request();
 
-  if(get_config()->client_proxy &&
-     downstream->get_request_method() != "CONNECT") {
+  if (get_config()->client_proxy &&
+      downstream->get_request_method() != "CONNECT") {
     // Make sure that request path is an absolute URI.
     http_parser_url u;
     auto url = downstream->get_request_path().c_str();
     memset(&u, 0, sizeof(u));
-    rv = http_parser_parse_url(url,
-                               downstream->get_request_path().size(),
-                               0, &u);
-    if(rv != 0 || !(u.field_set & (1 << UF_SCHEMA))) {
+    rv = http_parser_parse_url(url, downstream->get_request_path().size(), 0,
+                               &u);
+    if (rv != 0 || !(u.field_set & (1 << UF_SCHEMA))) {
       // Expect to respond with 400 bad request
       return -1;
     }
   }
 
-  rv =  downstream->attach_downstream_connection
-    (upstream->get_client_handler()->get_downstream_connection());
+  rv = downstream->attach_downstream_connection(
+      upstream->get_client_handler()->get_downstream_connection());
 
-  if(rv != 0) {
+  if (rv != 0) {
     downstream->set_request_state(Downstream::CONNECT_FAIL);
 
     return -1;
@@ -195,7 +182,7 @@ int htp_hdrs_completecb(http_parser *htp)
 
   rv = downstream->push_request_headers();
 
-  if(rv != 0) {
+  if (rv != 0) {
     return -1;
   }
 
@@ -206,14 +193,13 @@ int htp_hdrs_completecb(http_parser *htp)
 } // namespace
 
 namespace {
-int htp_bodycb(http_parser *htp, const char *data, size_t len)
-{
+int htp_bodycb(http_parser *htp, const char *data, size_t len) {
   int rv;
-  auto upstream = static_cast<HttpsUpstream*>(htp->data);
+  auto upstream = static_cast<HttpsUpstream *>(htp->data);
   auto downstream = upstream->get_downstream();
-  rv = downstream->push_upload_data_chunk
-    (reinterpret_cast<const uint8_t*>(data), len);
-  if(rv != 0) {
+  rv = downstream->push_upload_data_chunk(
+      reinterpret_cast<const uint8_t *>(data), len);
+  if (rv != 0) {
     return -1;
   }
   return 0;
@@ -221,17 +207,16 @@ int htp_bodycb(http_parser *htp, const char *data, size_t len)
 } // namespace
 
 namespace {
-int htp_msg_completecb(http_parser *htp)
-{
+int htp_msg_completecb(http_parser *htp) {
   int rv;
-  auto upstream = static_cast<HttpsUpstream*>(htp->data);
-  if(LOG_ENABLED(INFO)) {
+  auto upstream = static_cast<HttpsUpstream *>(htp->data);
+  if (LOG_ENABLED(INFO)) {
     ULOG(INFO, upstream) << "HTTP request completed";
   }
   auto downstream = upstream->get_downstream();
   downstream->set_request_state(Downstream::MSG_COMPLETE);
   rv = downstream->end_upload_data();
-  if(rv != 0) {
+  if (rv != 0) {
     return -1;
   }
   // Stop further processing to complete this request
@@ -242,52 +227,50 @@ int htp_msg_completecb(http_parser *htp)
 
 namespace {
 http_parser_settings htp_hooks = {
-  htp_msg_begin, // http_cb      on_message_begin;
-  htp_uricb, // http_data_cb on_url;
-  nullptr, // http_data_cb on_status;
-  htp_hdr_keycb, // http_data_cb on_header_field;
-  htp_hdr_valcb, // http_data_cb on_header_value;
-  htp_hdrs_completecb, // http_cb      on_headers_complete;
-  htp_bodycb, // http_data_cb on_body;
-  htp_msg_completecb // http_cb      on_message_complete;
+    htp_msg_begin,       // http_cb      on_message_begin;
+    htp_uricb,           // http_data_cb on_url;
+    nullptr,             // http_data_cb on_status;
+    htp_hdr_keycb,       // http_data_cb on_header_field;
+    htp_hdr_valcb,       // http_data_cb on_header_value;
+    htp_hdrs_completecb, // http_cb      on_headers_complete;
+    htp_bodycb,          // http_data_cb on_body;
+    htp_msg_completecb   // http_cb      on_message_complete;
 };
 } // namespace
 
-
 // on_read() does not consume all available data in input buffer if
 // one http request is fully received.
-int HttpsUpstream::on_read()
-{
+int HttpsUpstream::on_read() {
   auto bev = handler_->get_bev();
   auto input = bufferevent_get_input(bev);
   auto downstream = get_downstream();
 
   // downstream can be nullptr here, because it is initialized in the
   // callback chain called by http_parser_execute()
-  if(downstream && downstream->get_upgraded()) {
-    for(;;) {
+  if (downstream && downstream->get_upgraded()) {
+    for (;;) {
       auto inputlen = evbuffer_get_contiguous_space(input);
 
-      if(inputlen == 0) {
+      if (inputlen == 0) {
         return 0;
       }
 
       auto mem = evbuffer_pullup(input, inputlen);
 
-      auto rv = downstream->push_upload_data_chunk
-        (reinterpret_cast<const uint8_t*>(mem), inputlen);
+      auto rv = downstream->push_upload_data_chunk(
+          reinterpret_cast<const uint8_t *>(mem), inputlen);
 
-      if(rv != 0) {
+      if (rv != 0) {
         return -1;
       }
 
-      if(evbuffer_drain(input, inputlen) != 0) {
+      if (evbuffer_drain(input, inputlen) != 0) {
         ULOG(FATAL, this) << "evbuffer_drain() failed";
         return -1;
       }
 
-      if(downstream->get_output_buffer_full()) {
-        if(LOG_ENABLED(INFO)) {
+      if (downstream->get_output_buffer_full()) {
+        if (LOG_ENABLED(INFO)) {
           ULOG(INFO, this) << "Downstream output buffer is full";
         }
         pause_read(SHRPX_NO_BUFFER);
@@ -297,20 +280,19 @@ int HttpsUpstream::on_read()
     }
   }
 
-  for(;;) {
+  for (;;) {
     auto inputlen = evbuffer_get_contiguous_space(input);
 
-    if(inputlen == 0) {
+    if (inputlen == 0) {
       return 0;
     }
 
     auto mem = evbuffer_pullup(input, inputlen);
 
-    auto nread = http_parser_execute(&htp_, &htp_hooks,
-                                     reinterpret_cast<const char*>(mem),
-                                     inputlen);
+    auto nread = http_parser_execute(
+        &htp_, &htp_hooks, reinterpret_cast<const char *>(mem), inputlen);
 
-    if(evbuffer_drain(input, nread) != 0) {
+    if (evbuffer_drain(input, nread) != 0) {
       ULOG(FATAL, this) << "evbuffer_drain() failed";
       return -1;
     }
@@ -325,15 +307,15 @@ int HttpsUpstream::on_read()
     auto handler = get_client_handler();
     auto htperr = HTTP_PARSER_ERRNO(&htp_);
 
-    if(htperr == HPE_PAUSED) {
+    if (htperr == HPE_PAUSED) {
 
       assert(downstream);
 
-      if(downstream->get_request_state() == Downstream::CONNECT_FAIL) {
+      if (downstream->get_request_state() == Downstream::CONNECT_FAIL) {
         handler->set_should_close_after_write(true);
         // Following paues_read is needed to avoid reading next data.
         pause_read(SHRPX_MSG_BLOCK);
-        if(error_reply(503) != 0) {
+        if (error_reply(503) != 0) {
           return -1;
         }
         // Downstream gets deleted after response body is read.
@@ -342,7 +324,7 @@ int HttpsUpstream::on_read()
 
       assert(downstream->get_request_state() == Downstream::MSG_COMPLETE);
 
-      if(downstream->get_downstream_connection() == nullptr) {
+      if (downstream->get_downstream_connection() == nullptr) {
         // Error response has already be sent
         assert(downstream->get_response_state() == Downstream::MSG_COMPLETE);
         delete_downstream();
@@ -350,10 +332,10 @@ int HttpsUpstream::on_read()
         return 0;
       }
 
-      if(handler->get_http2_upgrade_allowed() &&
-         downstream->get_http2_upgrade_request()) {
+      if (handler->get_http2_upgrade_allowed() &&
+          downstream->get_http2_upgrade_request()) {
 
-        if(handler->perform_http2_upgrade(this) != 0) {
+        if (handler->perform_http2_upgrade(this) != 0) {
           return -1;
         }
 
@@ -365,8 +347,8 @@ int HttpsUpstream::on_read()
       return 0;
     }
 
-    if(htperr != HPE_OK) {
-      if(LOG_ENABLED(INFO)) {
+    if (htperr != HPE_OK) {
+      if (LOG_ENABLED(INFO)) {
         ULOG(INFO, this) << "HTTP parse failure: "
                          << "(" << http_errno_name(htperr) << ") "
                          << http_errno_description(htperr);
@@ -377,14 +359,14 @@ int HttpsUpstream::on_read()
 
       unsigned int status_code;
 
-      if(downstream && downstream->get_request_state() ==
-         Downstream::CONNECT_FAIL) {
+      if (downstream &&
+          downstream->get_request_state() == Downstream::CONNECT_FAIL) {
         status_code = 503;
       } else {
         status_code = 400;
       }
 
-      if(error_reply(status_code) != 0) {
+      if (error_reply(status_code) != 0) {
         return -1;
       }
 
@@ -392,8 +374,8 @@ int HttpsUpstream::on_read()
     }
 
     // downstream can be NULL here.
-    if(downstream && downstream->get_output_buffer_full()) {
-      if(LOG_ENABLED(INFO)) {
+    if (downstream && downstream->get_output_buffer_full()) {
+      if (LOG_ENABLED(INFO)) {
         ULOG(INFO, this) << "Downstream output buffer is full";
       }
 
@@ -404,15 +386,14 @@ int HttpsUpstream::on_read()
   }
 }
 
-int HttpsUpstream::on_write()
-{
+int HttpsUpstream::on_write() {
   int rv = 0;
   auto downstream = get_downstream();
-  if(downstream) {
+  if (downstream) {
     // We need to postpone detachment until all data are sent so that
     // we can notify nghttp2 library all data consumed.
-    if(downstream->get_response_state() == Downstream::MSG_COMPLETE) {
-      if(downstream->get_response_connection_close()) {
+    if (downstream->get_response_state() == Downstream::MSG_COMPLETE) {
+      if (downstream->get_response_connection_close()) {
         // Connection close
         downstream->pop_downstream_connection();
         // dconn was deleted
@@ -421,7 +402,7 @@ int HttpsUpstream::on_write()
         downstream->detach_downstream_connection();
       }
       // We need this if response ends before request.
-      if(downstream->get_request_state() == Downstream::MSG_COMPLETE) {
+      if (downstream->get_request_state() == Downstream::MSG_COMPLETE) {
         delete_downstream();
         return resume_read(SHRPX_MSG_BLOCK, nullptr, 0);
       }
@@ -433,25 +414,17 @@ int HttpsUpstream::on_write()
   return rv;
 }
 
-int HttpsUpstream::on_event()
-{
-  return 0;
-}
+int HttpsUpstream::on_event() { return 0; }
 
-ClientHandler* HttpsUpstream::get_client_handler() const
-{
-  return handler_;
-}
+ClientHandler *HttpsUpstream::get_client_handler() const { return handler_; }
 
-void HttpsUpstream::pause_read(IOCtrlReason reason)
-{
+void HttpsUpstream::pause_read(IOCtrlReason reason) {
   ioctrl_.pause_read(reason);
 }
 
 int HttpsUpstream::resume_read(IOCtrlReason reason, Downstream *downstream,
-                               size_t consumed)
-{
-  if(ioctrl_.resume_read(reason)) {
+                               size_t consumed) {
+  if (ioctrl_.resume_read(reason)) {
     // Process remaining data in input buffer here because these bytes
     // are not notified by readcb until new data arrive.
     http_parser_pause(&htp_, 0);
@@ -462,23 +435,22 @@ int HttpsUpstream::resume_read(IOCtrlReason reason, Downstream *downstream,
 }
 
 namespace {
-void https_downstream_readcb(bufferevent *bev, void *ptr)
-{
-  auto dconn = static_cast<DownstreamConnection*>(ptr);
+void https_downstream_readcb(bufferevent *bev, void *ptr) {
+  auto dconn = static_cast<DownstreamConnection *>(ptr);
   auto downstream = dconn->get_downstream();
-  auto upstream = static_cast<HttpsUpstream*>(downstream->get_upstream());
+  auto upstream = static_cast<HttpsUpstream *>(downstream->get_upstream());
   int rv;
 
   rv = downstream->on_read();
 
-  if(downstream->get_response_state() == Downstream::MSG_RESET) {
+  if (downstream->get_response_state() == Downstream::MSG_RESET) {
     delete upstream->get_client_handler();
 
     return;
   }
 
-  if(rv != 0) {
-    if(downstream->get_response_state() == Downstream::HEADER_COMPLETE) {
+  if (rv != 0) {
+    if (downstream->get_response_state() == Downstream::HEADER_COMPLETE) {
       // We already sent HTTP response headers to upstream
       // client. Just close the upstream connection.
       delete upstream->get_client_handler();
@@ -488,17 +460,17 @@ void https_downstream_readcb(bufferevent *bev, void *ptr)
 
     // We did not sent any HTTP response, so sent error
     // response. Cannot reuse downstream connection in this case.
-    if(upstream->error_reply(502) != 0) {
+    if (upstream->error_reply(502) != 0) {
       delete upstream->get_client_handler();
 
       return;
     }
 
-    if(downstream->get_request_state() == Downstream::MSG_COMPLETE) {
+    if (downstream->get_request_state() == Downstream::MSG_COMPLETE) {
       upstream->delete_downstream();
 
       // Process next HTTP request
-      if(upstream->resume_read(SHRPX_MSG_BLOCK, nullptr, 0) == -1) {
+      if (upstream->resume_read(SHRPX_MSG_BLOCK, nullptr, 0) == -1) {
         return;
       }
     }
@@ -508,8 +480,8 @@ void https_downstream_readcb(bufferevent *bev, void *ptr)
 
   auto handler = upstream->get_client_handler();
 
-  if(downstream->get_response_state() != Downstream::MSG_COMPLETE) {
-    if(handler->get_outbuf_length() >= OUTBUF_MAX_THRES) {
+  if (downstream->get_response_state() != Downstream::MSG_COMPLETE) {
+    if (handler->get_outbuf_length() >= OUTBUF_MAX_THRES) {
       downstream->pause_read(SHRPX_NO_BUFFER);
     }
 
@@ -518,8 +490,8 @@ void https_downstream_readcb(bufferevent *bev, void *ptr)
 
   // If pending data exist, we defer detachment to correctly notify
   // the all consumed data to nghttp2 library.
-  if(handler->get_outbuf_length() == 0) {
-    if(downstream->get_response_connection_close()) {
+  if (handler->get_outbuf_length() == 0) {
+    if (downstream->get_response_connection_close()) {
       // Connection close
       downstream->pop_downstream_connection();
 
@@ -530,9 +502,9 @@ void https_downstream_readcb(bufferevent *bev, void *ptr)
     }
   }
 
-  if(downstream->get_request_state() == Downstream::MSG_COMPLETE) {
-    if(handler->get_should_close_after_write() &&
-       handler->get_outbuf_length() == 0) {
+  if (downstream->get_request_state() == Downstream::MSG_COMPLETE) {
+    if (handler->get_should_close_after_write() &&
+        handler->get_outbuf_length() == 0) {
       // If all upstream response body has already written out to
       // the peer, we cannot use writecb for ClientHandler. In
       // this case, we just delete handler here.
@@ -544,14 +516,14 @@ void https_downstream_readcb(bufferevent *bev, void *ptr)
     upstream->delete_downstream();
 
     // Process next HTTP request
-    if(upstream->resume_read(SHRPX_MSG_BLOCK, nullptr, 0) == -1) {
+    if (upstream->resume_read(SHRPX_MSG_BLOCK, nullptr, 0) == -1) {
       return;
     }
 
     return;
   }
 
-  if(downstream->get_upgraded()) {
+  if (downstream->get_upgraded()) {
     // This path is effectively only taken for HTTP2 downstream
     // because only HTTP2 downstream sets response_state to
     // MSG_COMPLETE and this function. For HTTP downstream, EOF
@@ -559,7 +531,7 @@ void https_downstream_readcb(bufferevent *bev, void *ptr)
     // https_downstream_eventcb.
     //
     // Tunneled connection always indicates connection close.
-    if(handler->get_outbuf_length() == 0) {
+    if (handler->get_outbuf_length() == 0) {
       // For tunneled connection, if there is no pending data,
       // delete handler because on_write will not be called.
       delete handler;
@@ -567,7 +539,7 @@ void https_downstream_readcb(bufferevent *bev, void *ptr)
       return;
     }
 
-    if(LOG_ENABLED(INFO)) {
+    if (LOG_ENABLED(INFO)) {
       DLOG(INFO, downstream) << "Tunneled connection has pending data";
     }
 
@@ -575,48 +547,46 @@ void https_downstream_readcb(bufferevent *bev, void *ptr)
   }
 
   // Delete handler here if we have no pending write.
-  if(handler->get_should_close_after_write() &&
-     handler->get_outbuf_length() == 0) {
+  if (handler->get_should_close_after_write() &&
+      handler->get_outbuf_length() == 0) {
     delete handler;
   }
 }
 } // namespace
 
 namespace {
-void https_downstream_writecb(bufferevent *bev, void *ptr)
-{
-  if(evbuffer_get_length(bufferevent_get_output(bev)) > 0) {
+void https_downstream_writecb(bufferevent *bev, void *ptr) {
+  if (evbuffer_get_length(bufferevent_get_output(bev)) > 0) {
     return;
   }
-  auto dconn = static_cast<DownstreamConnection*>(ptr);
+  auto dconn = static_cast<DownstreamConnection *>(ptr);
   auto downstream = dconn->get_downstream();
-  auto upstream = static_cast<HttpsUpstream*>(downstream->get_upstream());
+  auto upstream = static_cast<HttpsUpstream *>(downstream->get_upstream());
   // May return -1
   upstream->resume_read(SHRPX_NO_BUFFER, downstream, 0);
 }
 } // namespace
 
 namespace {
-void https_downstream_eventcb(bufferevent *bev, short events, void *ptr)
-{
-  auto dconn = static_cast<DownstreamConnection*>(ptr);
+void https_downstream_eventcb(bufferevent *bev, short events, void *ptr) {
+  auto dconn = static_cast<DownstreamConnection *>(ptr);
   auto downstream = dconn->get_downstream();
-  auto upstream = static_cast<HttpsUpstream*>(downstream->get_upstream());
-  if(events & BEV_EVENT_CONNECTED) {
-    if(LOG_ENABLED(INFO)) {
+  auto upstream = static_cast<HttpsUpstream *>(downstream->get_upstream());
+  if (events & BEV_EVENT_CONNECTED) {
+    if (LOG_ENABLED(INFO)) {
       DCLOG(INFO, dconn) << "Connection established";
     }
 
     return;
   }
 
-  if(events & BEV_EVENT_EOF) {
-    if(LOG_ENABLED(INFO)) {
+  if (events & BEV_EVENT_EOF) {
+    if (LOG_ENABLED(INFO)) {
       DCLOG(INFO, dconn) << "EOF";
     }
-    if(downstream->get_response_state() == Downstream::HEADER_COMPLETE) {
+    if (downstream->get_response_state() == Downstream::HEADER_COMPLETE) {
       // Server may indicate the end of the request by EOF
-      if(LOG_ENABLED(INFO)) {
+      if (LOG_ENABLED(INFO)) {
         DCLOG(INFO, dconn) << "The end of the response body was indicated by "
                            << "EOF";
       }
@@ -624,27 +594,27 @@ void https_downstream_eventcb(bufferevent *bev, short events, void *ptr)
       downstream->set_response_state(Downstream::MSG_COMPLETE);
 
       auto handler = upstream->get_client_handler();
-      if(handler->get_should_close_after_write() &&
-         handler->get_outbuf_length() == 0) {
+      if (handler->get_should_close_after_write() &&
+          handler->get_outbuf_length() == 0) {
         // If all upstream response body has already written out to
         // the peer, we cannot use writecb for ClientHandler. In this
         // case, we just delete handler here.
         delete handler;
         return;
       }
-    } else if(downstream->get_response_state() != Downstream::MSG_COMPLETE) {
+    } else if (downstream->get_response_state() != Downstream::MSG_COMPLETE) {
       // error
-      if(LOG_ENABLED(INFO)) {
+      if (LOG_ENABLED(INFO)) {
         DCLOG(INFO, dconn) << "Treated as error";
       }
-      if(upstream->error_reply(502) != 0) {
+      if (upstream->error_reply(502) != 0) {
         delete upstream->get_client_handler();
         return;
       }
     }
-    if(downstream->get_request_state() == Downstream::MSG_COMPLETE) {
+    if (downstream->get_request_state() == Downstream::MSG_COMPLETE) {
       upstream->delete_downstream();
-      if(upstream->resume_read(SHRPX_MSG_BLOCK, nullptr, 0) == -1) {
+      if (upstream->resume_read(SHRPX_MSG_BLOCK, nullptr, 0) == -1) {
         return;
       }
     }
@@ -652,29 +622,29 @@ void https_downstream_eventcb(bufferevent *bev, short events, void *ptr)
     return;
   }
 
-  if(events & (BEV_EVENT_ERROR | BEV_EVENT_TIMEOUT)) {
-    if(LOG_ENABLED(INFO)) {
-      if(events & BEV_EVENT_ERROR) {
+  if (events & (BEV_EVENT_ERROR | BEV_EVENT_TIMEOUT)) {
+    if (LOG_ENABLED(INFO)) {
+      if (events & BEV_EVENT_ERROR) {
         DCLOG(INFO, dconn) << "Network error";
       } else {
         DCLOG(INFO, dconn) << "Timeout";
       }
     }
-    if(downstream->get_response_state() == Downstream::INITIAL) {
+    if (downstream->get_response_state() == Downstream::INITIAL) {
       unsigned int status;
-      if(events & BEV_EVENT_TIMEOUT) {
+      if (events & BEV_EVENT_TIMEOUT) {
         status = 504;
       } else {
         status = 502;
       }
-      if(upstream->error_reply(status) != 0) {
+      if (upstream->error_reply(status) != 0) {
         delete upstream->get_client_handler();
         return;
       }
     }
-    if(downstream->get_request_state() == Downstream::MSG_COMPLETE) {
+    if (downstream->get_request_state() == Downstream::MSG_COMPLETE) {
       upstream->delete_downstream();
-      if(upstream->resume_read(SHRPX_MSG_BLOCK, nullptr, 0) == -1) {
+      if (upstream->resume_read(SHRPX_MSG_BLOCK, nullptr, 0) == -1) {
         return;
       }
     }
@@ -682,12 +652,11 @@ void https_downstream_eventcb(bufferevent *bev, short events, void *ptr)
 }
 } // namespace
 
-int HttpsUpstream::error_reply(unsigned int status_code)
-{
+int HttpsUpstream::error_reply(unsigned int status_code) {
   auto html = http::create_error_html(status_code);
   auto downstream = get_downstream();
 
-  if(downstream) {
+  if (downstream) {
     downstream->set_response_http_status(status_code);
   }
 
@@ -700,64 +669,61 @@ int HttpsUpstream::error_reply(unsigned int status_code)
   header += "\r\nContent-Length: ";
   header += util::utos(html.size());
   header += "\r\nContent-Type: text/html; charset=UTF-8\r\n";
-  if(get_client_handler()->get_should_close_after_write()) {
+  if (get_client_handler()->get_should_close_after_write()) {
     header += "Connection: close\r\n";
   }
   header += "\r\n";
   auto output = bufferevent_get_output(handler_->get_bev());
-  if(evbuffer_add(output, header.c_str(), header.size()) != 0 ||
-     evbuffer_add(output, html.c_str(), html.size()) != 0) {
+  if (evbuffer_add(output, header.c_str(), header.size()) != 0 ||
+      evbuffer_add(output, html.c_str(), html.size()) != 0) {
     ULOG(FATAL, this) << "evbuffer_add() failed";
     return -1;
   }
 
-  if(downstream) {
+  if (downstream) {
+    downstream->add_response_sent_bodylen(html.size());
     downstream->set_response_state(Downstream::MSG_COMPLETE);
+  } else {
+    handler_->write_accesslog(1, 1, status_code, html.size());
   }
 
   return 0;
 }
 
-bufferevent_data_cb HttpsUpstream::get_downstream_readcb()
-{
+bufferevent_data_cb HttpsUpstream::get_downstream_readcb() {
   return https_downstream_readcb;
 }
 
-bufferevent_data_cb HttpsUpstream::get_downstream_writecb()
-{
+bufferevent_data_cb HttpsUpstream::get_downstream_writecb() {
   return https_downstream_writecb;
 }
 
-bufferevent_event_cb HttpsUpstream::get_downstream_eventcb()
-{
+bufferevent_event_cb HttpsUpstream::get_downstream_eventcb() {
   return https_downstream_eventcb;
 }
 
-void HttpsUpstream::attach_downstream(std::unique_ptr<Downstream> downstream)
-{
+void HttpsUpstream::attach_downstream(std::unique_ptr<Downstream> downstream) {
   assert(!downstream_);
   downstream_ = std::move(downstream);
 }
 
-void HttpsUpstream::delete_downstream()
-{
+void HttpsUpstream::delete_downstream() {
+  if (downstream_ && downstream_->accesslog_ready()) {
+    handler_->write_accesslog(downstream_.get());
+  }
+
   downstream_.reset();
 }
 
-Downstream* HttpsUpstream::get_downstream() const
-{
-  return downstream_.get();
-}
+Downstream *HttpsUpstream::get_downstream() const { return downstream_.get(); }
 
-std::unique_ptr<Downstream> HttpsUpstream::pop_downstream()
-{
+std::unique_ptr<Downstream> HttpsUpstream::pop_downstream() {
   return std::unique_ptr<Downstream>(downstream_.release());
 }
 
-int HttpsUpstream::on_downstream_header_complete(Downstream *downstream)
-{
-  if(LOG_ENABLED(INFO)) {
-    if(downstream->get_non_final_response()) {
+int HttpsUpstream::on_downstream_header_complete(Downstream *downstream) {
+  if (LOG_ENABLED(INFO)) {
+    if (downstream->get_non_final_response()) {
       DLOG(INFO, downstream) << "HTTP non-final response header";
     } else {
       DLOG(INFO, downstream) << "HTTP response header completed";
@@ -772,24 +738,24 @@ int HttpsUpstream::on_downstream_header_complete(Downstream *downstream)
   hdrs += http2::get_status_string(downstream->get_response_http_status());
   hdrs += "\r\n";
   downstream->normalize_response_headers();
-  if(!get_config()->http2_proxy && !get_config()->client_proxy &&
-     !get_config()->no_location_rewrite) {
-    downstream->rewrite_norm_location_response_header
-      (get_client_handler()->get_upstream_scheme(), get_config()->port);
+  if (!get_config()->http2_proxy && !get_config()->client_proxy &&
+      !get_config()->no_location_rewrite) {
+    downstream->rewrite_norm_location_response_header(
+        get_client_handler()->get_upstream_scheme(), get_config()->port);
   }
   auto end_headers = std::end(downstream->get_response_headers());
-  http2::build_http1_headers_from_norm_headers
-    (hdrs, downstream->get_response_headers());
+  http2::build_http1_headers_from_norm_headers(
+      hdrs, downstream->get_response_headers());
 
-  if(downstream->get_non_final_response()) {
+  if (downstream->get_non_final_response()) {
     hdrs += "\r\n";
 
-    if(LOG_ENABLED(INFO)) {
+    if (LOG_ENABLED(INFO)) {
       log_response_headers(hdrs);
     }
 
     auto output = bufferevent_get_output(handler_->get_bev());
-    if(evbuffer_add(output, hdrs.c_str(), hdrs.size()) != 0) {
+    if (evbuffer_add(output, hdrs.c_str(), hdrs.size()) != 0) {
       ULOG(FATAL, this) << "evbuffer_add() failed";
       return -1;
     }
@@ -801,28 +767,30 @@ int HttpsUpstream::on_downstream_header_complete(Downstream *downstream)
 
   // We check downstream->get_response_connection_close() in case when
   // the Content-Length is not available.
-  if(!downstream->get_request_connection_close() &&
-     !downstream->get_response_connection_close()) {
-    if(downstream->get_request_major() <= 0 ||
-       downstream->get_request_minor() <= 0) {
+  if (!downstream->get_request_connection_close() &&
+      !downstream->get_response_connection_close()) {
+    if (downstream->get_request_major() <= 0 ||
+        downstream->get_request_minor() <= 0) {
       // We add this header for HTTP/1.0 or HTTP/0.9 clients
       hdrs += "Connection: Keep-Alive\r\n";
     }
-  } else if(!downstream->get_upgraded() ||
-            downstream->get_request_method() != "CONNECT") {
+  } else if (!downstream->get_upgraded() ||
+             downstream->get_request_method() != "CONNECT") {
     hdrs += "Connection: close\r\n";
   }
 
-  if(downstream->get_norm_response_header("alt-svc") == end_headers) {
+  if (downstream->get_norm_response_header("alt-svc") == end_headers) {
     // We won't change or alter alt-svc from backend at the moment.
-    if(!get_config()->altsvcs.empty()) {
+    if (!get_config()->altsvcs.empty()) {
       hdrs += "Alt-Svc: ";
 
-      for(auto& altsvc : get_config()->altsvcs) {
+      for (auto &altsvc : get_config()->altsvcs) {
         hdrs += util::percent_encode_token(altsvc.protocol_id);
-        hdrs += "=";
+        hdrs += "=\"";
+        hdrs += util::quote_string(std::string(altsvc.host, altsvc.host_len));
+        hdrs += ":";
         hdrs += util::utos(altsvc.port);
-        hdrs += ", ";
+        hdrs += "\", ";
       }
 
       hdrs[hdrs.size() - 2] = '\r';
@@ -830,13 +798,13 @@ int HttpsUpstream::on_downstream_header_complete(Downstream *downstream)
     }
   }
 
-  if(!get_config()->http2_proxy && !get_config()->client_proxy) {
+  if (!get_config()->http2_proxy && !get_config()->client_proxy) {
     hdrs += "Server: ";
     hdrs += get_config()->server_name;
     hdrs += "\r\n";
   } else {
     auto server = downstream->get_norm_response_header("server");
-    if(server != end_headers) {
+    if (server != end_headers) {
       hdrs += "Server: ";
       hdrs += (*server).value;
       hdrs += "\r\n";
@@ -844,8 +812,8 @@ int HttpsUpstream::on_downstream_header_complete(Downstream *downstream)
   }
 
   auto via = downstream->get_norm_response_header("via");
-  if(get_config()->no_via) {
-    if(via != end_headers) {
+  if (get_config()->no_via) {
+    if (via != end_headers) {
       hdrs += "Via: ";
       hdrs += (*via).value;
       http2::sanitize_header_value(hdrs, hdrs.size() - (*via).value.size());
@@ -853,17 +821,17 @@ int HttpsUpstream::on_downstream_header_complete(Downstream *downstream)
     }
   } else {
     hdrs += "Via: ";
-    if(via != end_headers) {
+    if (via != end_headers) {
       hdrs += (*via).value;
       http2::sanitize_header_value(hdrs, hdrs.size() - (*via).value.size());
       hdrs += ", ";
     }
-    hdrs += http::create_via_header_value
-      (downstream->get_response_major(), downstream->get_response_minor());
+    hdrs += http::create_via_header_value(downstream->get_response_major(),
+                                          downstream->get_response_minor());
     hdrs += "\r\n";
   }
 
-  for(auto& p : get_config()->add_response_headers) {
+  for (auto &p : get_config()->add_response_headers) {
     hdrs += p.first;
     hdrs += ": ";
     hdrs += p.second;
@@ -872,54 +840,47 @@ int HttpsUpstream::on_downstream_header_complete(Downstream *downstream)
 
   hdrs += "\r\n";
 
-  if(LOG_ENABLED(INFO)) {
+  if (LOG_ENABLED(INFO)) {
     log_response_headers(hdrs);
   }
 
   auto output = bufferevent_get_output(handler_->get_bev());
-  if(evbuffer_add(output, hdrs.c_str(), hdrs.size()) != 0) {
+  if (evbuffer_add(output, hdrs.c_str(), hdrs.size()) != 0) {
     ULOG(FATAL, this) << "evbuffer_add() failed";
     return -1;
   }
 
-  if(downstream->get_upgraded()) {
-    upstream_accesslog(this->get_client_handler()->get_ipaddr(),
-                       downstream->get_response_http_status(), downstream);
-  }
-
-  downstream->clear_response_headers();
-  downstream->clear_request_headers();
-
   return 0;
 }
 
 int HttpsUpstream::on_downstream_body(Downstream *downstream,
                                       const uint8_t *data, size_t len,
-                                      bool flush)
-{
+                                      bool flush) {
   int rv;
-  if(len == 0) {
+  if (len == 0) {
     return 0;
   }
   auto output = bufferevent_get_output(handler_->get_bev());
-  if(downstream->get_chunked_response()) {
+  if (downstream->get_chunked_response()) {
     auto chunk_size_hex = util::utox(len);
     chunk_size_hex += "\r\n";
 
     rv = evbuffer_add(output, chunk_size_hex.c_str(), chunk_size_hex.size());
 
-    if(rv != 0) {
+    if (rv != 0) {
       ULOG(FATAL, this) << "evbuffer_add() failed";
       return -1;
     }
   }
-  if(evbuffer_add(output, data, len) != 0) {
+  if (evbuffer_add(output, data, len) != 0) {
     ULOG(FATAL, this) << "evbuffer_add() failed";
     return -1;
   }
 
-  if(downstream->get_chunked_response()) {
-    if(evbuffer_add(output, "\r\n", 2) != 0) {
+  downstream->add_response_sent_bodylen(len);
+
+  if (downstream->get_chunked_response()) {
+    if (evbuffer_add(output, "\r\n", 2) != 0) {
       ULOG(FATAL, this) << "evbuffer_add() failed";
       return -1;
     }
@@ -927,27 +888,20 @@ int HttpsUpstream::on_downstream_body(Downstream *downstream,
   return 0;
 }
 
-int HttpsUpstream::on_downstream_body_complete(Downstream *downstream)
-{
-  if(downstream->get_chunked_response()) {
+int HttpsUpstream::on_downstream_body_complete(Downstream *downstream) {
+  if (downstream->get_chunked_response()) {
     auto output = bufferevent_get_output(handler_->get_bev());
-    if(evbuffer_add(output, "0\r\n\r\n", 5) != 0) {
+    if (evbuffer_add(output, "0\r\n\r\n", 5) != 0) {
       ULOG(FATAL, this) << "evbuffer_add() failed";
       return -1;
     }
   }
-  if(LOG_ENABLED(INFO)) {
+  if (LOG_ENABLED(INFO)) {
     DLOG(INFO, downstream) << "HTTP response completed";
   }
 
-  if(!downstream->get_upgraded()) {
-    upstream_accesslog(get_client_handler()->get_ipaddr(),
-                       downstream->get_response_http_status(),
-                       downstream);
-  }
-
-  if(downstream->get_request_connection_close() ||
-     downstream->get_response_connection_close()) {
+  if (downstream->get_request_connection_close() ||
+      downstream->get_response_connection_close()) {
     auto handler = get_client_handler();
     handler->set_should_close_after_write(true);
   }
@@ -955,16 +909,14 @@ int HttpsUpstream::on_downstream_body_complete(Downstream *downstream)
 }
 
 int HttpsUpstream::on_downstream_abort_request(Downstream *downstream,
-                                               unsigned int status_code)
-{
+                                               unsigned int status_code) {
   return error_reply(status_code);
 }
 
-void HttpsUpstream::log_response_headers(const std::string& hdrs) const
-{
+void HttpsUpstream::log_response_headers(const std::string &hdrs) const {
   const char *hdrp;
   std::string nhdrs;
-  if(worker_config->errorlog_tty) {
+  if (worker_config->errorlog_tty) {
     nhdrs = http::colorizeHeaders(hdrs.c_str());
     hdrp = nhdrs.c_str();
   } else {
@@ -973,10 +925,15 @@ void HttpsUpstream::log_response_headers(const std::string& hdrs) const
   ULOG(INFO, this) << "HTTP response headers\n" << hdrp;
 }
 
-void HttpsUpstream::reset_timeouts()
-{
+void HttpsUpstream::reset_timeouts() {
   handler_->set_upstream_timeouts(&get_config()->upstream_read_timeout,
                                   &get_config()->upstream_write_timeout);
 }
 
+void HttpsUpstream::on_handler_delete() {
+  if (downstream_ && downstream_->accesslog_ready()) {
+    handler_->write_accesslog(downstream_.get());
+  }
+}
+
 } // namespace shrpx
