@@ -48,13 +48,12 @@ using namespace nghttp2;
 namespace shrpx {
 
 namespace {
-void evlistener_disable_cb(evutil_socket_t fd, short events, void *arg)
-{
-  auto listener_handler = static_cast<ListenHandler*>(arg);
+void evlistener_disable_cb(evutil_socket_t fd, short events, void *arg) {
+  auto listener_handler = static_cast<ListenHandler *>(arg);
 
   // If we are in graceful shutdown period, we must not enable
   // evlisteners again.
-  if(worker_config->graceful_shutdown) {
+  if (worker_config->graceful_shutdown) {
     return;
   }
 
@@ -64,46 +63,37 @@ void evlistener_disable_cb(evutil_socket_t fd, short events, void *arg)
 
 ListenHandler::ListenHandler(event_base *evbase, SSL_CTX *sv_ssl_ctx,
                              SSL_CTX *cl_ssl_ctx)
-  : evbase_(evbase),
-    sv_ssl_ctx_(sv_ssl_ctx),
-    cl_ssl_ctx_(cl_ssl_ctx),
-    rate_limit_group_(bufferevent_rate_limit_group_new
-                      (evbase, get_config()->worker_rate_limit_cfg)),
-    evlistener4_(nullptr),
-    evlistener6_(nullptr),
-    evlistener_disable_timerev_(evtimer_new(evbase,
-                                            evlistener_disable_cb, this)),
-    worker_stat_(util::make_unique<WorkerStat>()),
-    num_worker_shutdown_(0),
-    worker_round_robin_cnt_(0)
-{}
+    : evbase_(evbase), sv_ssl_ctx_(sv_ssl_ctx), cl_ssl_ctx_(cl_ssl_ctx),
+      rate_limit_group_(bufferevent_rate_limit_group_new(
+          evbase, get_config()->worker_rate_limit_cfg)),
+      evlistener4_(nullptr), evlistener6_(nullptr),
+      evlistener_disable_timerev_(
+          evtimer_new(evbase, evlistener_disable_cb, this)),
+      worker_stat_(util::make_unique<WorkerStat>()), num_worker_shutdown_(0),
+      worker_round_robin_cnt_(0) {}
 
-ListenHandler::~ListenHandler()
-{
+ListenHandler::~ListenHandler() {
   bufferevent_rate_limit_group_free(rate_limit_group_);
 }
 
-void ListenHandler::worker_reopen_log_files()
-{
+void ListenHandler::worker_reopen_log_files() {
   WorkerEvent wev;
 
   memset(&wev, 0, sizeof(wev));
   wev.type = REOPEN_LOG;
 
-  for(auto& info : workers_) {
+  for (auto &info : workers_) {
     bufferevent_write(info->bev, &wev, sizeof(wev));
   }
 }
 
 #ifndef NOTHREADS
 namespace {
-void worker_writecb(bufferevent *bev, void *ptr)
-{
-  auto listener_handler = static_cast<ListenHandler*>(ptr);
+void worker_writecb(bufferevent *bev, void *ptr) {
+  auto listener_handler = static_cast<ListenHandler *>(ptr);
   auto output = bufferevent_get_output(bev);
 
-  if(!worker_config->graceful_shutdown ||
-     evbuffer_get_length(output) != 0) {
+  if (!worker_config->graceful_shutdown || evbuffer_get_length(output) != 0) {
     return;
   }
 
@@ -119,16 +109,15 @@ void worker_writecb(bufferevent *bev, void *ptr)
 } // namespace
 #endif // NOTHREADS
 
-void ListenHandler::create_worker_thread(size_t num)
-{
+void ListenHandler::create_worker_thread(size_t num) {
 #ifndef NOTHREADS
   workers_.resize(0);
-  for(size_t i = 0; i < num; ++i) {
+  for (size_t i = 0; i < num; ++i) {
     int rv;
     auto info = util::make_unique<WorkerInfo>();
     rv = socketpair(AF_UNIX, SOCK_STREAM | SOCK_NONBLOCK | SOCK_CLOEXEC, 0,
                     info->sv);
-    if(rv == -1) {
+    if (rv == -1) {
       auto error = errno;
       LLOG(ERROR, this) << "socketpair() failed: errno=" << error;
       continue;
@@ -137,14 +126,14 @@ void ListenHandler::create_worker_thread(size_t num)
     info->sv_ssl_ctx = sv_ssl_ctx_;
     info->cl_ssl_ctx = cl_ssl_ctx_;
 
-    info->fut = std::async(std::launch::async, start_threaded_worker,
-                           info.get());
+    info->fut =
+        std::async(std::launch::async, start_threaded_worker, info.get());
 
-    auto bev = bufferevent_socket_new(evbase_, info->sv[0],
-                                      BEV_OPT_DEFER_CALLBACKS);
-    if(!bev) {
+    auto bev =
+        bufferevent_socket_new(evbase_, info->sv[0], BEV_OPT_DEFER_CALLBACKS);
+    if (!bev) {
       LLOG(ERROR, this) << "bufferevent_socket_new() failed";
-      for(size_t j = 0; j < 2; ++j) {
+      for (size_t j = 0; j < 2; ++j) {
         close(info->sv[j]);
       }
       continue;
@@ -156,26 +145,25 @@ void ListenHandler::create_worker_thread(size_t num)
 
     workers_.push_back(std::move(info));
 
-    if(LOG_ENABLED(INFO)) {
+    if (LOG_ENABLED(INFO)) {
       LLOG(INFO, this) << "Created thread #" << workers_.size() - 1;
     }
   }
 #endif // NOTHREADS
 }
 
-void ListenHandler::join_worker()
-{
+void ListenHandler::join_worker() {
 #ifndef NOTHREADS
   int n = 0;
 
-  if(LOG_ENABLED(INFO)) {
+  if (LOG_ENABLED(INFO)) {
     LLOG(INFO, this) << "Waiting for worker thread to join: n="
                      << workers_.size();
   }
 
-  for(auto& worker : workers_) {
+  for (auto &worker : workers_) {
     worker->fut.get();
-    if(LOG_ENABLED(INFO)) {
+    if (LOG_ENABLED(INFO)) {
       LLOG(INFO, this) << "Thread #" << n << " joined";
     }
     ++n;
@@ -183,44 +171,42 @@ void ListenHandler::join_worker()
 #endif // NOTHREADS
 }
 
-void ListenHandler::graceful_shutdown_worker()
-{
-  if(get_config()->num_worker == 1) {
+void ListenHandler::graceful_shutdown_worker() {
+  if (get_config()->num_worker == 1) {
     return;
   }
 
-  for(auto& worker : workers_) {
+  for (auto &worker : workers_) {
     WorkerEvent wev;
     memset(&wev, 0, sizeof(wev));
     wev.type = GRACEFUL_SHUTDOWN;
 
-    if(LOG_ENABLED(INFO)) {
+    if (LOG_ENABLED(INFO)) {
       LLOG(INFO, this) << "Sending graceful shutdown signal to worker";
     }
 
     auto output = bufferevent_get_output(worker->bev);
 
-    if(evbuffer_add(output, &wev, sizeof(wev)) != 0) {
+    if (evbuffer_add(output, &wev, sizeof(wev)) != 0) {
       LLOG(FATAL, this) << "evbuffer_add() failed";
     }
   }
 }
 
-int ListenHandler::accept_connection(evutil_socket_t fd,
-                                     sockaddr *addr, int addrlen)
-{
-  if(LOG_ENABLED(INFO)) {
+int ListenHandler::accept_connection(evutil_socket_t fd, sockaddr *addr,
+                                     int addrlen) {
+  if (LOG_ENABLED(INFO)) {
     LLOG(INFO, this) << "Accepted connection. fd=" << fd;
   }
 
   evutil_make_socket_closeonexec(fd);
 
-  if(get_config()->num_worker == 1) {
+  if (get_config()->num_worker == 1) {
 
-    if(worker_stat_->num_connections >=
-       get_config()->worker_frontend_connections) {
+    if (worker_stat_->num_connections >=
+        get_config()->worker_frontend_connections) {
 
-      if(LOG_ENABLED(INFO)) {
+      if (LOG_ENABLED(INFO)) {
         TLOG(INFO, this) << "Too many connections >="
                          << get_config()->worker_frontend_connections;
       }
@@ -229,11 +215,10 @@ int ListenHandler::accept_connection(evutil_socket_t fd,
       return -1;
     }
 
-    auto client = ssl::accept_connection(evbase_, rate_limit_group_,
-                                         sv_ssl_ctx_, fd, addr, addrlen,
-                                         worker_stat_.get(),
-                                         &dconn_pool_);
-    if(!client) {
+    auto client =
+        ssl::accept_connection(evbase_, rate_limit_group_, sv_ssl_ctx_, fd,
+                               addr, addrlen, worker_stat_.get(), &dconn_pool_);
+    if (!client) {
       LLOG(ERROR, this) << "ClientHandler creation failed";
 
       close(fd);
@@ -254,7 +239,7 @@ int ListenHandler::accept_connection(evutil_socket_t fd,
   memcpy(&wev.client_addr, addr, addrlen);
   wev.client_addrlen = addrlen;
   auto output = bufferevent_get_output(workers_[idx]->bev);
-  if(evbuffer_add(output, &wev, sizeof(wev)) != 0) {
+  if (evbuffer_add(output, &wev, sizeof(wev)) != 0) {
     LLOG(FATAL, this) << "evbuffer_add() failed";
     close(fd);
     return -1;
@@ -263,86 +248,69 @@ int ListenHandler::accept_connection(evutil_socket_t fd,
   return 0;
 }
 
-event_base* ListenHandler::get_evbase() const
-{
-  return evbase_;
-}
+event_base *ListenHandler::get_evbase() const { return evbase_; }
 
-int ListenHandler::create_http2_session()
-{
+int ListenHandler::create_http2_session() {
   int rv;
   http2session_ = util::make_unique<Http2Session>(evbase_, cl_ssl_ctx_);
   rv = http2session_->init_notification();
   return rv;
 }
 
-int ListenHandler::create_http1_connect_blocker()
-{
+int ListenHandler::create_http1_connect_blocker() {
   int rv;
   http1_connect_blocker_ = util::make_unique<ConnectBlocker>();
 
   rv = http1_connect_blocker_->init(evbase_);
 
-  if(rv != 0) {
+  if (rv != 0) {
     return -1;
   }
 
   return 0;
 }
 
-const WorkerStat* ListenHandler::get_worker_stat() const
-{
+const WorkerStat *ListenHandler::get_worker_stat() const {
   return worker_stat_.get();
 }
 
-void ListenHandler::set_evlistener4(evconnlistener *evlistener4)
-{
+void ListenHandler::set_evlistener4(evconnlistener *evlistener4) {
   evlistener4_ = evlistener4;
 }
 
-evconnlistener* ListenHandler::get_evlistener4() const
-{
-  return evlistener4_;
-}
+evconnlistener *ListenHandler::get_evlistener4() const { return evlistener4_; }
 
-void ListenHandler::set_evlistener6(evconnlistener *evlistener6)
-{
+void ListenHandler::set_evlistener6(evconnlistener *evlistener6) {
   evlistener6_ = evlistener6;
 }
 
-evconnlistener* ListenHandler::get_evlistener6() const
-{
-  return evlistener6_;
-}
+evconnlistener *ListenHandler::get_evlistener6() const { return evlistener6_; }
 
-void ListenHandler::enable_evlistener()
-{
-  if(evlistener4_) {
+void ListenHandler::enable_evlistener() {
+  if (evlistener4_) {
     evconnlistener_enable(evlistener4_);
   }
 
-  if(evlistener6_) {
+  if (evlistener6_) {
     evconnlistener_enable(evlistener6_);
   }
 }
 
-void ListenHandler::disable_evlistener()
-{
-  if(evlistener4_) {
+void ListenHandler::disable_evlistener() {
+  if (evlistener4_) {
     evconnlistener_disable(evlistener4_);
   }
 
-  if(evlistener6_) {
+  if (evlistener6_) {
     evconnlistener_disable(evlistener6_);
   }
 }
 
-void ListenHandler::disable_evlistener_temporary(const timeval *timeout)
-{
+void ListenHandler::disable_evlistener_temporary(const timeval *timeout) {
   int rv;
 
-  if(timeout->tv_sec == 0 ||
-     evtimer_pending(evlistener_disable_timerev_, nullptr)) {
+  if (timeout->tv_sec == 0 ||
+      evtimer_pending(evlistener_disable_timerev_, nullptr)) {
     return;
   }
 
@@ -350,29 +318,28 @@ void ListenHandler::disable_evlistener_temporary(const timeval *timeout)
 
   rv = evtimer_add(evlistener_disable_timerev_, timeout);
 
-  if(rv < 0) {
+  if (rv < 0) {
     LOG(ERROR) << "evtimer_add for evlistener_disable_timerev_ failed";
   }
 }
 
 namespace {
 void perform_accept_pending_connection(ListenHandler *listener_handler,
-                                       evconnlistener *listener)
-{
-  if(!listener) {
+                                       evconnlistener *listener) {
+  if (!listener) {
     return;
   }
 
   auto server_fd = evconnlistener_get_fd(listener);
 
-  for(;;) {
+  for (;;) {
     sockaddr_union sockaddr;
     socklen_t addrlen = sizeof(sockaddr);
 
     auto fd = accept(server_fd, &sockaddr.sa, &addrlen);
 
-    if(fd == -1) {
-      switch(errno) {
+    if (fd == -1) {
+      switch (errno) {
       case EINTR:
       case ENETDOWN:
       case EPROTO:
@@ -397,15 +364,13 @@ void perform_accept_pending_connection(ListenHandler *listener_handler,
 }
 } // namespace
 
-void ListenHandler::accept_pending_connection()
-{
+void ListenHandler::accept_pending_connection() {
   perform_accept_pending_connection(this, evlistener4_);
   perform_accept_pending_connection(this, evlistener6_);
 }
 
-void ListenHandler::notify_worker_shutdown()
-{
-  if(++num_worker_shutdown_ == workers_.size()) {
+void ListenHandler::notify_worker_shutdown() {
+  if (++num_worker_shutdown_ == workers_.size()) {
     event_base_loopbreak(evbase_);
   }
 }
