@@ -48,14 +48,15 @@ public:
   virtual bufferevent_data_cb get_downstream_readcb() = 0;
   virtual bufferevent_data_cb get_downstream_writecb() = 0;
   virtual bufferevent_event_cb get_downstream_eventcb() = 0;
-  virtual ClientHandler* get_client_handler() const = 0;
+  virtual ClientHandler *get_client_handler() const = 0;
 
   virtual int on_downstream_header_complete(Downstream *downstream) = 0;
-  virtual int on_downstream_body(Downstream *downstream,
-                                 const uint8_t *data, size_t len,
-                                 bool flush) = 0;
+  virtual int on_downstream_body(Downstream *downstream, const uint8_t *data,
+                                 size_t len, bool flush) = 0;
   virtual int on_downstream_body_complete(Downstream *downstream) = 0;
 
+  virtual void on_handler_delete() = 0;
+
   virtual void pause_read(IOCtrlReason reason) = 0;
   virtual int resume_read(IOCtrlReason reason, Downstream *downstream,
                           size_t consumed) = 0;
