@@ -27,16 +27,12 @@
 namespace shrpx {
 
 WorkerConfig::WorkerConfig()
-  : accesslog_fd(-1),
-    errorlog_fd(-1),
-    errorlog_tty(false),
-    graceful_shutdown(false)
-{}
+    : accesslog_fd(-1), errorlog_fd(-1), errorlog_tty(false),
+      graceful_shutdown(false) {}
 
 #ifndef NOTHREADS
 thread_local
 #endif // NOTHREADS
-WorkerConfig *worker_config = new WorkerConfig();
+    WorkerConfig *worker_config = new WorkerConfig();
 
 } // namespace shrpx
-
