@@ -39,16 +39,23 @@ namespace ssl {
 // mozilla.
 //
 // https://wiki.mozilla.org/Security/Server_Side_TLS
-const char* const DEFAULT_CIPHER_LIST = "ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:DHE-DSS-AES128-GCM-SHA256:kEDH+AESGCM:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-AES128-SHA256:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-AES256-SHA384:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-DSS-AES128-SHA256:DHE-RSA-AES256-SHA256:DHE-DSS-AES256-SHA:DHE-RSA-AES256-SHA:!aNULL:!eNULL:!EXPORT:!DES:!RC4:!3DES:!MD5:!PSK";
+const char *const DEFAULT_CIPHER_LIST =
+    "ECDHE-RSA-AES128-GCM-SHA256:ECDHE-ECDSA-AES128-GCM-SHA256:ECDHE-RSA-"
+    "AES256-GCM-SHA384:ECDHE-ECDSA-AES256-GCM-SHA384:DHE-RSA-AES128-GCM-SHA256:"
+    "DHE-DSS-AES128-GCM-SHA256:kEDH+AESGCM:ECDHE-RSA-AES128-SHA256:ECDHE-ECDSA-"
+    "AES128-SHA256:ECDHE-RSA-AES128-SHA:ECDHE-ECDSA-AES128-SHA:ECDHE-RSA-"
+    "AES256-SHA384:ECDHE-ECDSA-AES256-SHA384:ECDHE-RSA-AES256-SHA:ECDHE-ECDSA-"
+    "AES256-SHA:DHE-RSA-AES128-SHA256:DHE-RSA-AES128-SHA:DHE-DSS-AES128-SHA256:"
+    "DHE-RSA-AES256-SHA256:DHE-DSS-AES256-SHA:DHE-RSA-AES256-SHA:!aNULL:!eNULL:"
+    "!EXPORT:!DES:!RC4:!3DES:!MD5:!PSK";
 
 namespace {
 std::vector<std::mutex> ssl_global_locks;
 } // namespace
 
 namespace {
-void ssl_locking_cb(int mode, int type, const char *file, int line)
-{
-  if(mode & CRYPTO_LOCK) {
+void ssl_locking_cb(int mode, int type, const char *file, int line) {
+  if (mode & CRYPTO_LOCK) {
     ssl_global_locks[type].lock();
   } else {
     ssl_global_locks[type].unlock();
@@ -56,9 +63,8 @@ void ssl_locking_cb(int mode, int type, const char *file, int line)
 }
 } // namespace
 
-LibsslGlobalLock::LibsslGlobalLock()
-{
-  if(!ssl_global_locks.empty()) {
+LibsslGlobalLock::LibsslGlobalLock() {
+  if (!ssl_global_locks.empty()) {
     std::cerr << "OpenSSL global lock has been already set" << std::endl;
     assert(0);
   }
@@ -70,10 +76,7 @@ LibsslGlobalLock::LibsslGlobalLock()
   CRYPTO_set_locking_callback(ssl_locking_cb);
 }
 
-LibsslGlobalLock::~LibsslGlobalLock()
-{
-  ssl_global_locks.clear();
-}
+LibsslGlobalLock::~LibsslGlobalLock() { ssl_global_locks.clear(); }
 
 } // namespace ssl
 
